@@ -48,7 +48,7 @@ static HANDLE			gThreadHandle = NULL;
 afs_int32
 afsd_ServicePerformFlushVolumeCmd(char *data)
 {
-    register afs_int32 code;
+    afs_int32 code;
     struct ViceIoctl blob;
 
     afsi_log("Flushing Volume \"%s\"",data);
@@ -64,18 +64,18 @@ afsd_ServicePerformFlushVolumes()
     CONST CHAR	COLON = ':';
     CONST CHAR	SLASH = '\\';
     CONST DWORD	NETRESBUFSIZE = 16384;
-    CHAR		bufMessage[1024];
-    UINT		i;
-    DWORD		dwServerSize;
-    DWORD		dwRet;
-    DWORD		dwCount;
-    DWORD		dwNetResBufSize;
-    DWORD		dwTotalVols = 0;
-    DWORD		dwVolBegin, dwVolEnd;
-    DWORD		dwFlushBegin, dwFlushEnd;
-    HANDLE		hEnum;
+    CHAR	bufMessage[1024];
+    UINT	i;
+    DWORD	dwServerSize;
+    DWORD	dwRet;
+    DWORD	dwCount;
+    DWORD	dwNetResBufSize;
+    DWORD	dwTotalVols = 0;
+    DWORD	dwVolBegin, dwVolEnd;
+    DWORD	dwFlushBegin, dwFlushEnd;
+    HANDLE	hEnum;
     LPNETRESOURCE	lpNetResBuf, lpnr;
-    PCHAR		pszShareName, pc;
+    char        *pszShareName, *pc;
     afs_int32	afsRet = 0;
 
     if ( lana_OnlyLoopback() ) {
@@ -152,7 +152,7 @@ afsd_ServicePerformFlushVolumes()
             {
                 // got one!
                 // but we don't want to flush '\\[...]afs\all'
-                if (_stricmp(lpnr->lpRemoteName, pszShareName) == 0)
+                if (cm_stricmp_utf8(lpnr->lpRemoteName, pszShareName) == 0)
                     continue;
                 ++dwTotalVols;
 
