@@ -47,6 +47,6 @@ extern long cm_ValidateACLCache(void);
 
 extern long cm_ShutdownACLCache(void);
 
-extern void cm_ResetACLCache(cm_user_t *userp);
+extern void cm_ResetACLCache(cm_cell_t *cellp, cm_user_t *userp);
 
 #endif  /* _CM_ACLENT_H_ */
