@@ -10,8 +10,6 @@
 #include <afsconfig.h>
 #include "afs/param.h"
 
-RCSID
-    ("$Header: /cvs/openafs/src/afs/AIX/osi_vnodeops.c,v 1.18.4.1 2009/01/26 18:52:39 shadow Exp $");
 
 #include "h/systm.h"
 #include "h/types.h"
@@ -1624,7 +1622,7 @@ afs_gn_strategy(struct buf *abp)
 
 int
 afs_inactive(struct vcache *avc, 
-	     struct AFS_UCRED *acred)
+	     AFS_UCRED *acred)
 {
     afs_InactiveVCache(avc, acred);
 }
