@@ -14,8 +14,6 @@
 #include <afsconfig.h>
 #include "afs/param.h"
 
-RCSID
-    ("$Header: /cvs/openafs/src/afs/LINUX/osi_module.c,v 1.74.2.8 2007/08/22 02:17:52 shadow Exp $");
 
 #include <linux/module.h> /* early to avoid printf->printk mapping */
 #include "afs/sysincludes.h"
@@ -38,6 +36,8 @@ RCSID
 #include <linux/kernel.h>
 #endif
 
+#include "osi_pagecopy.h"
+
 extern struct file_system_type afs_fs_type;
 
 #if !defined(AFS_LINUX24_ENV)
@@ -66,7 +66,7 @@ init_module(void)
 #endif
 {
     int err;
-    RWLOCK_INIT(&afs_xosi, "afs_xosi");
+    AFS_RWLOCK_INIT(&afs_xosi, "afs_xosi");
 
 #if !defined(AFS_LINUX24_ENV)
     /* obtain PAGE_OFFSET value */
@@ -117,6 +117,10 @@ init_module(void)
     osi_proc_init();
     osi_ioctl_init();
 #endif
+#if defined(AFS_CACHE_BYPASS)
+    afs_warn("Cache bypass patched libafs module init.\n");
+#endif
+    afs_init_pagecopy();
 
     return 0;
 }
@@ -129,6 +133,12 @@ void
 cleanup_module(void)
 #endif
 {
+#if defined(AFS_CACHE_BYPASS)
+    afs_warn("Cache bypass patched libafs module cleaning up.\n");
+#endif
+
+    afs_shutdown_pagecopy();
+
 #ifdef LINUX_KEYRING_SUPPORT
     osi_keyring_shutdown();
 #endif
@@ -150,6 +160,7 @@ cleanup_module(void)
     osi_ioctl_clean();
     osi_proc_clean();
 #endif
+
     return;
 }
 
