@@ -21,8 +21,6 @@
 #include <afsconfig.h>
 #include "afs/param.h"
 
-RCSID
-    ("$Header: /cvs/openafs/src/afs/LINUX/osi_vnodeops.c,v 1.126.2.54 2009/05/27 00:47:53 shadow Exp $");
 
 #include "afs/sysincludes.h"
 #include "afsincludes.h"
@@ -44,12 +42,18 @@ RCSID
 #include "afs/afs_bypasscache.h"
 #endif
 
+#include "osi_pagecopy.h"
+
 #ifdef pgoff2loff
 #define pageoff(pp) pgoff2loff((pp)->index)
 #else
 #define pageoff(pp) pp->offset
 #endif
 
+#ifndef HAVE_PAGEVEC_LRU_ADD_FILE
+#define __pagevec_lru_add_file __pagevec_lru_add
+#endif
+
 #ifndef MAX_ERRNO
 #define MAX_ERRNO 1000L
 #endif
@@ -80,28 +84,68 @@ extern struct afs_cacheOps afs_UfsCacheOps;
     } while(0);
 #endif /* AFS_LINUX24_ENV */
 
+
+/* This function converts a positive error code from AFS into a negative
+ * code suitable for passing into the Linux VFS layer. It checks that the
+ * error code is within the permissable bounds for the ERR_PTR mechanism.
+ *
+ * _All_ error codes which come from the AFS layer should be passed through
+ * this function before being returned to the kernel.
+ */
+
+static inline int afs_convert_code(int code) {
+    if ((code >= 0) && (code <= MAX_ERRNO))
+	return -code;
+    else
+	return -EIO;
+}
+
+/* Linux doesn't require a credp for many functions, and crref is an expensive
+ * operation. This helper function avoids obtaining it for VerifyVCache calls
+ */
+
+static inline int afs_linux_VerifyVCache(struct vcache *avc, cred_t **retcred) {
+    cred_t *credp = NULL;
+    struct vrequest treq;
+    int code;
+
+    if (avc->f.states & CStatd) {
+        if (retcred)
+            *retcred = NULL;
+	return 0;
+    }
+
+    credp = crref();
+
+    code = afs_InitReq(&treq, credp);
+    if (code == 0)
+        code = afs_VerifyVCache2(avc, &treq);
+
+    if (retcred != NULL)
+        *retcred = credp;
+    else
+        crfree(credp);
+
+    return afs_convert_code(code);
+}
+
 static ssize_t
 afs_linux_read(struct file *fp, char *buf, size_t count, loff_t * offp)
 {
-    ssize_t code;
+    ssize_t code = 0;
     struct vcache *vcp = VTOAFS(fp->f_dentry->d_inode);
-    cred_t *credp = crref();
-    struct vrequest treq;
+#if defined(AFS_CACHE_BYPASS) && LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,0)
     afs_size_t isize, offindex;
+#endif
+
     AFS_GLOCK();
     afs_Trace4(afs_iclSetp, CM_TRACE_READOP, ICL_TYPE_POINTER, vcp,
 	       ICL_TYPE_OFFSET, offp, ICL_TYPE_INT32, count, ICL_TYPE_INT32,
 	       99999);
-    /* get a validated vcache entry */
-    code = afs_InitReq(&treq, credp);
-    if (!code)
-	code = afs_VerifyVCache(vcp, &treq);
+    code = afs_linux_VerifyVCache(vcp, NULL);
 
-    if (code)
-	code = -code;
-    else {
-#if defined(AFS_CACHE_BYPASS)
-#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,0)
+    if (code == 0) {
+#if defined(AFS_CACHE_BYPASS) && LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,0)
 	isize = (i_size_read(fp->f_mapping->host) - 1) >> PAGE_CACHE_SHIFT;
         offindex = *offp >> PAGE_CACHE_SHIFT;
         if(offindex > isize) {
@@ -109,8 +153,9 @@ afs_linux_read(struct file *fp, char *buf, size_t count, loff_t * offp)
             goto done;
         }
 #endif
-#endif
-	osi_FlushPages(vcp, credp);	/* ensure stale pages are gone */
+	/* Linux's FlushPages implementation doesn't ever use credp,
+	 * so we optimise by not using it */
+	osi_FlushPages(vcp, NULL);	/* ensure stale pages are gone */
 	AFS_GUNLOCK();
 #ifdef DO_SYNC_READ
 	code = do_sync_read(fp, buf, count, offp);
@@ -123,9 +168,10 @@ afs_linux_read(struct file *fp, char *buf, size_t count, loff_t * offp)
     afs_Trace4(afs_iclSetp, CM_TRACE_READOP, ICL_TYPE_POINTER, vcp,
 	       ICL_TYPE_OFFSET, offp, ICL_TYPE_INT32, count, ICL_TYPE_INT32,
 	       code);
+#if defined(AFS_CACHE_BYPASS) && LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,0)
 done:
+#endif
     AFS_GUNLOCK();
-    crfree(credp);
     return code;
 }
 
@@ -139,8 +185,7 @@ afs_linux_write(struct file *fp, const char *buf, size_t count, loff_t * offp)
 {
     ssize_t code = 0;
     struct vcache *vcp = VTOAFS(fp->f_dentry->d_inode);
-    struct vrequest treq;
-    cred_t *credp = crref();
+    cred_t *credp;
 
     AFS_GLOCK();
 
@@ -148,18 +193,12 @@ afs_linux_write(struct file *fp, const char *buf, size_t count, loff_t * offp)
 	       ICL_TYPE_OFFSET, offp, ICL_TYPE_INT32, count, ICL_TYPE_INT32,
 	       (fp->f_flags & O_APPEND) ? 99998 : 99999);
 
-
-    /* get a validated vcache entry */
-    code = (ssize_t) afs_InitReq(&treq, credp);
-    if (!code)
-	code = (ssize_t) afs_VerifyVCache(vcp, &treq);
+    code = afs_linux_VerifyVCache(vcp, &credp);
 
     ObtainWriteLock(&vcp->lock, 529);
     afs_FakeOpen(vcp);
     ReleaseWriteLock(&vcp->lock);
-    if (code)
-	code = -code;
-    else {
+    if (code == 0) {
 	    AFS_GUNLOCK();
 #ifdef DO_SYNC_READ
 	    code = do_sync_write(fp, buf, count, offp);
@@ -170,6 +209,10 @@ afs_linux_write(struct file *fp, const char *buf, size_t count, loff_t * offp)
     }
 
     ObtainWriteLock(&vcp->lock, 530);
+
+    if (vcp->execsOrWriters == 1 && !credp)
+      credp = crref();
+
     afs_FakeClose(vcp, credp);
     ReleaseWriteLock(&vcp->lock);
 
@@ -177,8 +220,9 @@ afs_linux_write(struct file *fp, const char *buf, size_t count, loff_t * offp)
 	       ICL_TYPE_OFFSET, offp, ICL_TYPE_INT32, count, ICL_TYPE_INT32,
 	       code);
 
+    if (credp)
+      crfree(credp);
     AFS_GUNLOCK();
-    crfree(credp);
     return code;
 }
 
@@ -210,19 +254,19 @@ afs_linux_readdir(struct file *fp, void *dirbuf, filldir_t filldir)
     AFS_GLOCK();
     AFS_STATCNT(afs_readdir);
 
-    code = afs_InitReq(&treq, credp);
+    code = afs_convert_code(afs_InitReq(&treq, credp));
     crfree(credp);
     if (code)
 	goto out1;
 
     afs_InitFakeStat(&fakestat);
-    code = afs_EvalFakeStat(&avc, &fakestat, &treq);
+    code = afs_convert_code(afs_EvalFakeStat(&avc, &fakestat, &treq));
     if (code)
 	goto out;
 
     /* update the cache entry */
   tagain:
-    code = afs_VerifyVCache(avc, &treq);
+    code = afs_convert_code(afs_VerifyVCache2(avc, &treq));
     if (code)
 	goto out;
 
@@ -288,7 +332,7 @@ afs_linux_readdir(struct file *fp, void *dirbuf, filldir_t filldir)
 	else {
 	    printf("afs_linux_readdir: afs_dir_GetBlob failed, null name (inode %lx, dirpos %d)\n", 
 		   (unsigned long)&tdc->f.inode, dirpos);
-	    DRelease((struct buffer *) de, 0);
+	    DRelease(de, 0);
 	    ReleaseSharedLock(&avc->lock);
 	    afs_PutDCache(tdc);
 	    code = -ENOENT;
@@ -339,7 +383,7 @@ afs_linux_readdir(struct file *fp, void *dirbuf, filldir_t filldir)
 #else
 	code = (*filldir) (dirbuf, de->name, len, offset, ino);
 #endif
-	DRelease((struct buffer *)de, 0);
+	DRelease(de, 0);
 	if (code)
 	    break;
 	offset = dirpos + 1 + ((len + 16) >> 5);
@@ -386,8 +430,6 @@ static int
 afs_linux_mmap(struct file *fp, struct vm_area_struct *vmap)
 {
     struct vcache *vcp = VTOAFS(FILE_INODE(fp));
-    cred_t *credp = crref();
-    struct vrequest treq;
     int code;
 
     AFS_GLOCK();
@@ -403,30 +445,19 @@ afs_linux_mmap(struct file *fp, struct vm_area_struct *vmap)
 #endif
 
     /* get a validated vcache entry */
-    code = afs_InitReq(&treq, credp);
-    if (code)
-	goto out_err;
-
-    code = afs_VerifyVCache(vcp, &treq);
-    if (code)
-	goto out_err;
-
-    osi_FlushPages(vcp, credp);	/* ensure stale pages are gone */
+    code = afs_linux_VerifyVCache(vcp, NULL);
 
+    /* Linux's Flushpage implementation doesn't use credp, so optimise
+     * our code to not need to crref() it */
+    osi_FlushPages(vcp, NULL); /* ensure stale pages are gone */
     AFS_GUNLOCK();
     code = generic_file_mmap(fp, vmap);
     AFS_GLOCK();
     if (!code)
 	vcp->f.states |= CMAPPED;
 
-out:
     AFS_GUNLOCK();
-    crfree(credp);
     return code;
-
-out_err:
-    code = -code;
-    goto out;
 }
 
 static int
@@ -447,7 +478,7 @@ afs_linux_open(struct inode *ip, struct file *fp)
 #endif
 
     crfree(credp);
-    return -code;
+    return afs_convert_code(code);
 }
 
 static int
@@ -468,7 +499,7 @@ afs_linux_release(struct inode *ip, struct file *fp)
 #endif
 
     crfree(credp);
-    return -code;
+    return afs_convert_code(code);
 }
 
 static int
@@ -492,7 +523,7 @@ afs_linux_fsync(struct file *fp, struct dentry *dp)
     maybe_unlock_kernel();
 #endif
     crfree(credp);
-    return -code;
+    return afs_convert_code(code);
 
 }
 
@@ -534,21 +565,21 @@ afs_linux_lock(struct file *fp, int cmd, struct file_lock *flp)
 
 #ifdef AFS_LINUX24_ENV
     if ((code == 0 || flp->fl_type == F_UNLCK) && 
-	(cmd == F_SETLK || cmd == F_SETLKW)) {
+        (cmd == F_SETLK || cmd == F_SETLKW)) {
 # ifdef POSIX_LOCK_FILE_WAIT_ARG
-        code = posix_lock_file(fp, flp, 0);
+	code = posix_lock_file(fp, flp, 0);
 # else
-        flp->fl_flags &=~ FL_SLEEP;
-        code = posix_lock_file(fp, flp);
-# endif
-       if (code && flp->fl_type != F_UNLCK) {
-           struct AFS_FLOCK flock2;
-           flock2 = flock;
-           flock2.l_type = F_UNLCK;
-           AFS_GLOCK();
-           afs_lockctl(vcp, &flock2, F_SETLK, credp);
-           AFS_GUNLOCK();
-       }
+	flp->fl_flags &=~ FL_SLEEP;
+	code = posix_lock_file(fp, flp);
+# endif 
+	if (code && flp->fl_type != F_UNLCK) {
+	    struct AFS_FLOCK flock2;
+	    flock2 = flock;
+	    flock2.l_type = F_UNLCK;
+	    AFS_GLOCK();
+	    afs_lockctl(vcp, &flock2, F_SETLK, credp);
+	    AFS_GUNLOCK();
+	}
     }
     /* If lockctl says there are no conflicting locks, then also check with the
      * kernel, as lockctl knows nothing about byte range locks
@@ -575,8 +606,8 @@ afs_linux_lock(struct file *fp, int cmd, struct file_lock *flp)
             crfree(credp);
             return 0;
         }
-    }
 # endif
+    }
     
 #endif
     /* Convert flock back to Linux's file_lock */
@@ -586,8 +617,7 @@ afs_linux_lock(struct file *fp, int cmd, struct file_lock *flp)
     flp->fl_end = flock.l_start + flock.l_len - 1;
 
     crfree(credp);
-    return -code;
-
+    return afs_convert_code(code);
 }
 
 #ifdef STRUCT_FILE_OPERATIONS_HAS_FLOCK
@@ -637,7 +667,7 @@ afs_linux_flock(struct file *fp, int cmd, struct file_lock *flp) {
     flp->fl_pid = flock.l_pid;
 
     crfree(credp);
-    return -code;
+    return afs_convert_code(code);
 }
 #endif
 
@@ -712,7 +742,7 @@ out:
     AFS_GUNLOCK();
 
     crfree(credp);
-    return -code;
+    return afs_convert_code(code);
 }
 
 #if !defined(AFS_LINUX24_ENV)
@@ -812,7 +842,7 @@ check_bad_parent(struct dentry *dp)
 	credp = crref();
 
 	/* force a lookup, so vcp->mvid is fixed up */
-	afs_lookup(pvc, dp->d_name.name, &avc, credp);
+	afs_lookup(pvc, (char *)dp->d_name.name, &avc, credp);
 	if (!avc || vcp != avc) {	/* bad, very bad.. */
 	    afs_Trace4(afs_iclSetp, CM_TRACE_TMP_1S3L, ICL_TYPE_STRING,
 		       "check_bad_parent: bad pointer returned from afs_lookup origvc newvc dentry",
@@ -838,6 +868,9 @@ afs_linux_revalidate(struct dentry *dp)
     cred_t *credp;
     int code;
 
+    if (afs_shuttingdown)
+	return EIO;
+
 #ifdef AFS_LINUX24_ENV
     maybe_lock_kernel();
 #endif
@@ -858,8 +891,18 @@ afs_linux_revalidate(struct dentry *dp)
     }
 #endif
 
-    credp = crref();
-    code = afs_getattr(vcp, &vattr, credp);
+    /* This avoids the crref when we don't have to do it. Watch for
+     * changes in afs_getattr that don't get replicated here!
+     */
+    if (vcp->f.states & CStatd &&
+        (!afs_fakestat_enable || vcp->mvstat != 1) &&
+	!afs_nfsexporter) {
+	code = afs_CopyOutAttrs(vcp, &vattr);
+    } else {
+        credp = crref();
+	code = afs_getattr(vcp, &vattr, credp);
+	crfree(credp);
+    }
     if (!code)
         afs_fill_inode(AFSTOV(vcp), &vattr);
 
@@ -867,9 +910,8 @@ afs_linux_revalidate(struct dentry *dp)
 #ifdef AFS_LINUX24_ENV
     maybe_unlock_kernel();
 #endif
-    crfree(credp);
 
-    return -code;
+    return afs_convert_code(code);
 }
 
 #if defined(AFS_LINUX26_ENV)
@@ -972,7 +1014,7 @@ afs_linux_dentry_revalidate(struct dentry *dp)
 	if (hgetlo(pvcp->f.m.DataVersion) > dp->d_time || !(vcp->f.states & CStatd)) {
 
 	    credp = crref();
-	    afs_lookup(pvcp, dp->d_name.name, &tvc, credp);
+	    afs_lookup(pvcp, (char *)dp->d_name.name, &tvc, credp);
 	    if (!tvc || tvc != vcp)
 		goto bad_dentry;
 
@@ -1122,7 +1164,7 @@ afs_linux_create(struct inode *dip, struct dentry *dp, int mode)
     maybe_unlock_kernel();
 #endif
     crfree(credp);
-    return -code;
+    return afs_convert_code(code);
 }
 
 /* afs_linux_lookup */
@@ -1152,7 +1194,7 @@ afs_linux_lookup(struct inode *dip, struct dentry *dp)
     maybe_lock_kernel();
 #endif
     AFS_GLOCK();
-    code = afs_lookup(VTOAFS(dip), comp, &vcp, credp);
+    code = afs_lookup(VTOAFS(dip), (char *)comp, &vcp, credp);
     
     if (vcp) {
 	struct vattr vattr;
@@ -1222,14 +1264,12 @@ afs_linux_lookup(struct inode *dip, struct dentry *dp)
     if (code == ENOENT)
 	return ERR_PTR(0);
 #endif
-    else if ((code >= 0) && (code <= MAX_ERRNO))
-        return ERR_PTR(-code);
     else 
-	return ERR_PTR(-EIO);
+	return ERR_PTR(afs_convert_code(code));
 #else
     if (code == ENOENT)
 	code = 0;
-    return -code;
+    return afs_convert_code(code);
 #endif
 }
 
@@ -1247,11 +1287,11 @@ afs_linux_link(struct dentry *olddp, struct inode *dip, struct dentry *newdp)
     d_drop(newdp);
 
     AFS_GLOCK();
-    code = afs_link(VTOAFS(oldip), VTOAFS(dip), name, credp);
+    code = afs_link(VTOAFS(oldip), VTOAFS(dip), (char *)name, credp);
 
     AFS_GUNLOCK();
     crfree(credp);
-    return -code;
+    return afs_convert_code(code);
 }
 
 static int
@@ -1288,7 +1328,7 @@ afs_linux_unlink(struct inode *dip, struct dentry *dp)
 	} while (__dp->d_inode != NULL);
 
 	AFS_GLOCK();
-	code = afs_rename(VTOAFS(dip), dp->d_name.name, VTOAFS(dip), __dp->d_name.name, credp);
+	code = afs_rename(VTOAFS(dip), (char *)dp->d_name.name, VTOAFS(dip), (char *)__dp->d_name.name, credp);
 	if (!code) {
             tvc->mvid = (void *) __name;
             crhold(credp);
@@ -1321,7 +1361,7 @@ afs_linux_unlink(struct inode *dip, struct dentry *dp)
     }
 
     AFS_GLOCK();
-    code = afs_remove(VTOAFS(dip), name, credp);
+    code = afs_remove(VTOAFS(dip), (char *)name, credp);
     AFS_GUNLOCK();
     if (!code)
 	d_drop(dp);
@@ -1330,7 +1370,7 @@ out:
     maybe_unlock_kernel();
 #endif
     crfree(credp);
-    return -code;
+    return afs_convert_code(code);
 }
 
 
@@ -1349,10 +1389,10 @@ afs_linux_symlink(struct inode *dip, struct dentry *dp, const char *target)
 
     VATTR_NULL(&vattr);
     AFS_GLOCK();
-    code = afs_symlink(VTOAFS(dip), name, &vattr, target, credp);
+    code = afs_symlink(VTOAFS(dip), (char *)name, &vattr, (char *)target, credp);
     AFS_GUNLOCK();
     crfree(credp);
-    return -code;
+    return afs_convert_code(code);
 }
 
 static int
@@ -1371,7 +1411,7 @@ afs_linux_mkdir(struct inode *dip, struct dentry *dp, int mode)
     vattr.va_mask = ATTR_MODE;
     vattr.va_mode = mode;
     AFS_GLOCK();
-    code = afs_mkdir(VTOAFS(dip), name, &vattr, &tvcp, credp);
+    code = afs_mkdir(VTOAFS(dip), (char *)name, &vattr, &tvcp, credp);
 
     if (tvcp) {
 	struct inode *ip = AFSTOV(tvcp);
@@ -1389,7 +1429,7 @@ afs_linux_mkdir(struct inode *dip, struct dentry *dp, int mode)
     maybe_unlock_kernel();
 #endif
     crfree(credp);
-    return -code;
+    return afs_convert_code(code);
 }
 
 static int
@@ -1402,7 +1442,7 @@ afs_linux_rmdir(struct inode *dip, struct dentry *dp)
     /* locking kernel conflicts with glock? */
 
     AFS_GLOCK();
-    code = afs_rmdir(VTOAFS(dip), name, credp);
+    code = afs_rmdir(VTOAFS(dip), (char *)name, credp);
     AFS_GUNLOCK();
 
     /* Linux likes to see ENOTEMPTY returned from an rmdir() syscall
@@ -1418,7 +1458,7 @@ afs_linux_rmdir(struct inode *dip, struct dentry *dp)
     }
 
     crfree(credp);
-    return -code;
+    return afs_convert_code(code);
 }
 
 
@@ -1453,7 +1493,7 @@ afs_linux_rename(struct inode *oldip, struct dentry *olddp,
 #endif
 
     AFS_GLOCK();
-    code = afs_rename(VTOAFS(oldip), oldname, VTOAFS(newip), newname, credp);
+    code = afs_rename(VTOAFS(oldip), (char *)oldname, VTOAFS(newip), (char *)newname, credp);
     AFS_GUNLOCK();
 
     if (!code)
@@ -1467,7 +1507,7 @@ afs_linux_rename(struct inode *oldip, struct dentry *olddp,
 #endif
 
     crfree(credp);
-    return -code;
+    return afs_convert_code(code);
 }
 
 
@@ -1490,7 +1530,7 @@ afs_linux_ireadlink(struct inode *ip, char *target, int maxlen, uio_seg_t seg)
     if (!code)
 	return maxlen - tuio.uio_resid;
     else
-	return -code;
+	return afs_convert_code(code);
 }
 
 #if !defined(USABLE_KERNEL_PAGE_SYMLINK_CACHE)
@@ -1586,16 +1626,24 @@ afs_linux_follow_link(struct dentry *dp, struct dentry *basep,
 
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,0)
 
-/* The kernel calls readpages before trying readpage, with a list of 
- * pages.  The readahead algorithm expands num_pages when it thinks
- * the application will benefit.  Unlike readpage, the pages are not
- * necessarily allocated.  If we do not a) allocate required pages and 
- * b) remove them from page_list, linux will re-enter at afs_linux_readpage
- * for each required page (and the page will be pre-allocated) */	
+static inline int
+afs_linux_can_bypass(struct inode *ip) {
+    switch(cache_bypass_strategy) {
+	case NEVER_BYPASS_CACHE:
+	    return 0;
+	case ALWAYS_BYPASS_CACHE:
+	    return 1;
+	case LARGE_FILES_BYPASS_CACHE:
+	    if(i_size_read(ip) > cache_bypass_threshold)
+		return 1;
+	default:
+     }
+     return 0;
+}
 
 static int
-afs_linux_readpages(struct file *fp, struct address_space *mapping,
-		    struct list_head *page_list, unsigned num_pages)
+afs_linux_cache_bypass_read(struct file *fp, struct address_space *mapping,
+			    struct list_head *page_list, unsigned num_pages)
 {
     afs_int32 page_ix;
     uio_t *auio;
@@ -1614,34 +1662,6 @@ afs_linux_readpages(struct file *fp, struct address_space *mapping,
     afs_int32 page_count = 0;
     afs_int32 isize;
 	
-    credp = crref();
-	
-    switch(cache_bypass_strategy) {
-    case NEVER_BYPASS_CACHE:
-	break;	
-    case ALWAYS_BYPASS_CACHE:
-	bypasscache = 1;
-	break;
-    case LARGE_FILES_BYPASS_CACHE:
-	if(i_size_read(ip) > cache_bypass_threshold) {
-	    bypasscache = 1;
-	}
-	break;
-    default:
-	break;
-    }
-	
-    /* In the new incarnation of selective caching, a file's caching policy 
-     *  can change, eg because file size exceeds threshold, etc. */
-    trydo_cache_transition(avc, credp, bypasscache);	
-	 
-    if(!bypasscache) {
-	while(!list_empty(page_list)) {
-	    pp = list_entry(page_list->prev, struct page, lru);
-	    list_del(&pp->lru);
-	}
-	goto out;
-    }
     /* background thread must free: iovecp, auio, ancr */
     iovecp = osi_Alloc(num_pages * sizeof(struct iovec));
 
@@ -1715,7 +1735,9 @@ afs_linux_readpages(struct file *fp, struct address_space *mapping,
      * are in the LRU cache, then schedule the read */
     if(page_count) {
         pagevec_lru_add(&lrupv);
+	credp = crref();
         code = afs_ReadNoCache(avc, ancr, credp);
+	crfree(credp);
     } else {
         /* If there is nothing for the background thread to handle,
          * it won't be freeing the things that we never gave it */
@@ -1726,15 +1748,203 @@ afs_linux_readpages(struct file *fp, struct address_space *mapping,
     /* we do not flush, release, or unmap pages--that will be 
      * done for us by the background thread as each page comes in
      * from the fileserver */
-    crfree(credp);
-	
 out:	
-    return -code;
+    return afs_convert_code(code);
 }
 
 #endif /* LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,0) */
 #endif /* defined(AFS_CACHE_BYPASS */
 
+static int
+afs_linux_read_cache(struct file *cachefp, struct page *page,
+		     int chunk, struct pagevec *lrupv,
+		     struct afs_pagecopy_task *task) {
+    loff_t offset = page_offset(page);
+    struct page *newpage, *cachepage;
+    struct address_space *cachemapping;
+    int pageindex;
+    int code = 0;
+
+    cachemapping = cachefp->f_dentry->d_inode->i_mapping;
+    newpage = NULL;
+    cachepage = NULL;
+
+    /* From our offset, we now need to work out which page in the disk
+     * file it corresponds to. This will be fun ... */
+    pageindex = (offset - AFS_CHUNKTOBASE(chunk)) >> PAGE_CACHE_SHIFT;
+
+    while (cachepage == NULL) {
+        cachepage = find_get_page(cachemapping, pageindex);
+	if (!cachepage) {
+	    if (!newpage)
+		newpage = page_cache_alloc_cold(cachemapping);
+	    if (!newpage) {
+		code = -ENOMEM;
+		goto out;
+	    }
+
+	    code = add_to_page_cache(newpage, cachemapping,
+				     pageindex, GFP_KERNEL);
+	    if (code == 0) {
+	        cachepage = newpage;
+	        newpage = NULL;
+
+	        page_cache_get(cachepage);
+                if (!pagevec_add(lrupv, cachepage))
+                    __pagevec_lru_add_file(lrupv);
+
+	    } else {
+		page_cache_release(newpage);
+		newpage = NULL;
+		if (code != -EEXIST)
+		    goto out;
+	    }
+        } else {
+	    lock_page(cachepage);
+	}
+    }
+
+    if (!PageUptodate(cachepage)) {
+	ClearPageError(cachepage);
+        code = cachemapping->a_ops->readpage(NULL, cachepage);
+	if (!code && !task) {
+	    wait_on_page_locked(cachepage);
+	}
+    } else {
+        unlock_page(cachepage);
+    }
+
+    if (!code) {
+	if (PageUptodate(cachepage)) {
+	    copy_highpage(page, cachepage);
+	    flush_dcache_page(page);
+	    SetPageUptodate(page);
+	    UnlockPage(page);
+        } else if (task) {
+	    afs_pagecopy_queue_page(task, cachepage, page);
+	} else {
+	    code = -EIO;
+	}
+    }
+
+    if (code) {
+        UnlockPage(page);
+    }
+
+out:
+    if (cachepage)
+	page_cache_release(cachepage);
+
+    return code;
+}
+
+static int inline
+afs_linux_readpage_fastpath(struct file *fp, struct page *pp, int *codep)
+{
+    loff_t offset = page_offset(pp);
+    struct inode *ip = FILE_INODE(fp);
+    struct vcache *avc = VTOAFS(ip);
+    struct dcache *tdc;
+    struct file *cacheFp = NULL;
+    int code;
+    int dcLocked = 0;
+    struct pagevec lrupv;
+
+    /* Not a UFS cache, don't do anything */
+    if (cacheDiskType != AFS_FCACHE_TYPE_UFS)
+	return 0;
+
+    /* Can't do anything if the vcache isn't statd , or if the read
+     * crosses a chunk boundary.
+     */
+    if (!(avc->f.states & CStatd) ||
+        AFS_CHUNK(offset) != AFS_CHUNK(offset + PAGE_SIZE)) {
+	return 0;
+    }
+
+    ObtainWriteLock(&avc->lock, 911);
+
+    /* XXX - See if hinting actually makes things faster !!! */
+
+    /* See if we have a suitable entry already cached */
+    tdc = avc->dchint;
+
+    if (tdc) {
+        /* We need to lock xdcache, then dcache, to handle situations where
+         * the hint is on the free list. However, we can't safely do this
+         * according to the locking hierarchy. So, use a non blocking lock.
+         */
+	ObtainReadLock(&afs_xdcache);
+	dcLocked = ( 0 == NBObtainReadLock(&tdc->lock));
+
+	if (dcLocked && (tdc->index != NULLIDX)
+	    && !FidCmp(&tdc->f.fid, &avc->f.fid)
+	    && tdc->f.chunk == AFS_CHUNK(offset)
+	    && !(afs_indexFlags[tdc->index] & (IFFree | IFDiscarded))) {
+	    /* Bonus - the hint was correct */
+	    afs_RefDCache(tdc);
+	} else {
+	    /* Only destroy the hint if its actually invalid, not if there's
+	     * just been a locking failure */
+	    if (dcLocked) {
+		ReleaseReadLock(&tdc->lock);
+		avc->dchint = NULL;
+	    }
+
+	    tdc = NULL;
+	    dcLocked = 0;
+	}
+        ReleaseReadLock(&afs_xdcache);
+    }
+
+    /* No hint, or hint is no longer valid - see if we can get something
+     * directly from the dcache
+     */
+    if (!tdc)
+	tdc = afs_FindDCache(avc, offset);
+
+    if (!tdc) {
+	ReleaseWriteLock(&avc->lock);
+	return 0;
+    }
+
+    if (!dcLocked)
+	ObtainReadLock(&tdc->lock);
+
+    /* Is the dcache we've been given currently up to date */
+    if (!hsame(avc->f.m.DataVersion, tdc->f.versionNo) ||
+	(tdc->dflags & DFFetching)) {
+	ReleaseWriteLock(&avc->lock);
+	ReleaseReadLock(&tdc->lock);
+	afs_PutDCache(tdc);
+	return 0;
+    }
+
+    /* Update our hint for future abuse */
+    avc->dchint = tdc;
+
+    /* Okay, so we've now got a cache file that is up to date */
+
+    /* XXX - I suspect we should be locking the inodes before we use them! */
+    AFS_GUNLOCK();
+    cacheFp = afs_linux_raw_open(&tdc->f.inode, NULL);
+    pagevec_init(&lrupv, 0);
+
+    code = afs_linux_read_cache(cacheFp, pp, tdc->f.chunk, &lrupv, NULL);
+
+    if (pagevec_count(&lrupv))
+       __pagevec_lru_add_file(&lrupv);
+
+    filp_close(cacheFp, NULL);
+    AFS_GLOCK();
+
+    ReleaseReadLock(&tdc->lock);
+    ReleaseWriteLock(&avc->lock);
+    afs_PutDCache(tdc);
+
+    *codep = code;
+    return 1;
+}
 
 /* afs_linux_readpage
  * all reads come through here. A strategy-like read call.
@@ -1742,168 +1952,270 @@ out:
 static int
 afs_linux_readpage(struct file *fp, struct page *pp)
 {
-	 afs_int32 code;
-	 cred_t *credp = crref();
+    afs_int32 code;
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2,4,0)
-	 char *address;
-	 afs_offs_t offset = ((loff_t) pp->index) << PAGE_CACHE_SHIFT;
+    char *address;
+    afs_offs_t offset = ((loff_t) pp->index) << PAGE_CACHE_SHIFT;
 #else
-	 ulong address = afs_linux_page_address(pp);
-	 afs_offs_t offset = pageoff(pp);
+    ulong address = afs_linux_page_address(pp);
+    afs_offs_t offset = pageoff(pp);
 #endif
 #if defined(AFS_CACHE_BYPASS)
-	 afs_int32 bypasscache = 0; /* bypass for this read */
-	 struct nocache_read_request *ancr;
+    afs_int32 bypasscache = 0; /* bypass for this read */
+    struct nocache_read_request *ancr;
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,0)
+    afs_int32 isize;
 #endif
-	 afs_int32 isize;	
-	 uio_t *auio;
-	 struct iovec *iovecp;
-	 struct inode *ip = FILE_INODE(fp);
-	 afs_int32 cnt = page_count(pp);
-	 struct vcache *avc = VTOAFS(ip);
+#endif
+    uio_t *auio;
+    struct iovec *iovecp;
+    struct inode *ip = FILE_INODE(fp);
+    afs_int32 cnt = page_count(pp);
+    struct vcache *avc = VTOAFS(ip);
+    cred_t *credp;
 
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,0)
+    AFS_GLOCK();
+    if (afs_linux_readpage_fastpath(fp, pp, &code)) {
+	AFS_GUNLOCK();
+	return code;
+    }
+    AFS_GUNLOCK();
+#endif
+
+    credp = crref();
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2,4,0)
-	 address = kmap(pp);
-	 ClearPageError(pp);
+    address = kmap(pp);
+    ClearPageError(pp);
 #else
-	 atomic_add(1, &pp->count);
-	 set_bit(PG_locked, &pp->flags);	/* other bits? See mm.h */
-	 clear_bit(PG_error, &pp->flags);
+    atomic_add(1, &pp->count);
+    set_bit(PG_locked, &pp->flags);	/* other bits? See mm.h */
+    clear_bit(PG_error, &pp->flags);
 #endif
 #if defined(AFS_CACHE_BYPASS)
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,0)
-	 /* If the page is past the end of the file, skip it */
-	 isize = (i_size_read(fp->f_mapping->host) - 1) >> PAGE_CACHE_SHIFT;
-	 if(pp->index > isize) {
-		  if(PageLocked(pp))
-			   UnlockPage(pp);
-		  goto done;
-	 }
+    /* If the page is past the end of the file, skip it */
+    isize = (i_size_read(fp->f_mapping->host) - 1) >> PAGE_CACHE_SHIFT;
+    if(pp->index > isize) {
+	if(PageLocked(pp))
+	    UnlockPage(pp);
+	goto done;
+    }
 #endif
 #endif
-	 /* if bypasscache, receiver frees, else we do */
-	 auio = osi_Alloc(sizeof(uio_t));
-	 iovecp = osi_Alloc(sizeof(struct iovec));
-	
-	 setup_uio(auio, iovecp, (char *)address, offset, PAGE_SIZE, UIO_READ,
-			   AFS_UIOSYS);
+    /* if bypasscache, receiver frees, else we do */
+    auio = osi_Alloc(sizeof(uio_t));
+    iovecp = osi_Alloc(sizeof(struct iovec));
+
+    setup_uio(auio, iovecp, (char *)address, offset, PAGE_SIZE, UIO_READ,
+	      AFS_UIOSYS);
 
 #if defined(AFS_CACHE_BYPASS)
+    bypasscache = afs_linux_can_bypass(ip);
 
-	 switch(cache_bypass_strategy) {
-	 case NEVER_BYPASS_CACHE:
-		  break;	
-	 case ALWAYS_BYPASS_CACHE:
-		  bypasscache = 1;
-		  break;
-	 case LARGE_FILES_BYPASS_CACHE:
-		  if(i_size_read(ip) > cache_bypass_threshold) {
-			   bypasscache = 1;
-		  }
-		  break;
-	 default:
-		  break;
-	 }
+    /* In the new incarnation of selective caching, a file's caching policy
+     * can change, eg because file size exceeds threshold, etc. */
+    trydo_cache_transition(avc, credp, bypasscache);
+	
+    if(bypasscache) {
+	if(address)
+	    kunmap(pp);
+	/* save the page for background map */
+	auio->uio_iov->iov_base = (void*) pp;
+	/* the background thread will free this */
+	ancr = osi_Alloc(sizeof(struct nocache_read_request));
+	ancr->auio = auio;
+	ancr->offset = offset;
+	ancr->length = PAGE_SIZE;
 
-	 /* In the new incarnation of selective caching, a file's caching policy 
-	  * can change, eg because file size exceeds threshold, etc. */
-	 trydo_cache_transition(avc, credp, bypasscache);
-		
-	 if(bypasscache) {
-		  if(address)
-			   kunmap(pp);
-		  /* save the page for background map */
-		  auio->uio_iov->iov_base = (void*) pp;
-		  /* the background thread will free this */
-		  ancr = osi_Alloc(sizeof(struct nocache_read_request));
-		  ancr->auio = auio;
-		  ancr->offset = offset;
-		  ancr->length = PAGE_SIZE;
-	
-		  maybe_lock_kernel();
-		  code = afs_ReadNoCache(avc, ancr, credp);
-		  maybe_unlock_kernel();
-	
-		  goto done; /* skips release page, doing it in bg thread */
-	 }
+	maybe_lock_kernel();
+	code = afs_ReadNoCache(avc, ancr, credp);
+	maybe_unlock_kernel();
+
+	goto done; /* skips release page, doing it in bg thread */
+    }
 #endif 
 		  
 #ifdef AFS_LINUX24_ENV
-	 maybe_lock_kernel();
+    maybe_lock_kernel();
 #endif
-	 AFS_GLOCK();
-	 AFS_DISCON_LOCK();
-	 afs_Trace4(afs_iclSetp, CM_TRACE_READPAGE, ICL_TYPE_POINTER, ip, ICL_TYPE_POINTER, pp, ICL_TYPE_INT32, cnt, ICL_TYPE_INT32, 99999);	/* not a possible code value */
+    AFS_GLOCK();
+    AFS_DISCON_LOCK();
+    afs_Trace4(afs_iclSetp, CM_TRACE_READPAGE, ICL_TYPE_POINTER, ip,
+	       ICL_TYPE_POINTER, pp, ICL_TYPE_INT32, cnt, ICL_TYPE_INT32,
+	       99999);	/* not a possible code value */
 
-	 code = afs_rdwr(avc, auio, UIO_READ, 0, credp);
+    code = afs_rdwr(avc, auio, UIO_READ, 0, credp);
 	
-	 afs_Trace4(afs_iclSetp, CM_TRACE_READPAGE, ICL_TYPE_POINTER, ip,
-				ICL_TYPE_POINTER, pp, ICL_TYPE_INT32, cnt, ICL_TYPE_INT32,
-				code);
-	 AFS_DISCON_UNLOCK();
-	 AFS_GUNLOCK();
+    afs_Trace4(afs_iclSetp, CM_TRACE_READPAGE, ICL_TYPE_POINTER, ip,
+	       ICL_TYPE_POINTER, pp, ICL_TYPE_INT32, cnt, ICL_TYPE_INT32,
+	       code);
+    AFS_DISCON_UNLOCK();
+    AFS_GUNLOCK();
 #ifdef AFS_LINUX24_ENV
-	 maybe_unlock_kernel();
+    maybe_unlock_kernel();
 #endif
-	 if (!code) {	
-		  /* XXX valid for no-cache also?  Check last bits of files... :) 
-		   * Cognate code goes in afs_NoCacheFetchProc.  */
-		  if (auio->uio_resid)	/* zero remainder of page */
-			   memset((void *)(address + (PAGE_SIZE - auio->uio_resid)), 0,
-					  auio->uio_resid);
+    if (!code) {
+	/* XXX valid for no-cache also?  Check last bits of files... :)
+	 * Cognate code goes in afs_NoCacheFetchProc.  */
+	if (auio->uio_resid)	/* zero remainder of page */
+	     memset((void *)(address + (PAGE_SIZE - auio->uio_resid)), 0,
+		    auio->uio_resid);
 
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2,4,0)
-		  flush_dcache_page(pp);
-		  SetPageUptodate(pp);
+	flush_dcache_page(pp);
+	SetPageUptodate(pp);
 #else
-		  set_bit(PG_uptodate, &pp->flags);
+	set_bit(PG_uptodate, &pp->flags);
 #endif
-	 } /* !code */
+    } /* !code */
 
 #if LINUX_VERSION_CODE >= KERNEL_VERSION(2,4,0)
-	 kunmap(pp);
-	 UnlockPage(pp);
+    kunmap(pp);
+    UnlockPage(pp);
 #else
-	 clear_bit(PG_locked, &pp->flags);
-	 wake_up(&pp->wait);
-	 free_page(address);
+    clear_bit(PG_locked, &pp->flags);
+    wake_up(&pp->wait);
+    free_page(address);
 #endif
 
 #if defined(AFS_CACHE_BYPASS)
-
-/* do not call afs_GetDCache if cache is bypassed */
-	 if(bypasscache)
-		  goto done;
-	
+    /* do not call afs_GetDCache if cache is bypassed */
+    if(bypasscache)
+	goto done;
 #endif
 
-	 /* free if not bypassing cache */
-	 osi_Free(auio, sizeof(uio_t));
-	 osi_Free(iovecp, sizeof(struct iovec));
+    /* free if not bypassing cache */
+    osi_Free(auio, sizeof(uio_t));
+    osi_Free(iovecp, sizeof(struct iovec));
 
-	 if (!code && AFS_CHUNKOFFSET(offset) == 0) {
-		  struct dcache *tdc;
-		  struct vrequest treq;
+    if (!code && AFS_CHUNKOFFSET(offset) == 0) {
+	struct dcache *tdc;
+	struct vrequest treq;
 
-		  AFS_GLOCK();
-		  code = afs_InitReq(&treq, credp);
-		  if (!code && !NBObtainWriteLock(&avc->lock, 534)) {
-			   tdc = afs_FindDCache(avc, offset);
-			   if (tdc) {
-					if (!(tdc->mflags & DFNextStarted))
-						 afs_PrefetchChunk(avc, tdc, credp, &treq);
-					afs_PutDCache(tdc);
-			   }
-			   ReleaseWriteLock(&avc->lock);
-		  }
-		  AFS_GUNLOCK();
-	 }
+	AFS_GLOCK();
+	code = afs_InitReq(&treq, credp);
+	if (!code && !NBObtainWriteLock(&avc->lock, 534)) {
+	    tdc = afs_FindDCache(avc, offset);
+	    if (tdc) {
+		if (!(tdc->mflags & DFNextStarted))
+		    afs_PrefetchChunk(avc, tdc, credp, &treq);
+		    afs_PutDCache(tdc);
+	    }
+	    ReleaseWriteLock(&avc->lock);
+	}
+	AFS_GUNLOCK();
+    }
 
+#if defined(AFS_CACHE_BYPASS)
 done:
-	 crfree(credp);
-	 return -code;
+#endif
+    crfree(credp);
+    return afs_convert_code(code);
 }
 
+/* Readpages reads a number of pages for a particular file. We use
+ * this to optimise the reading, by limiting the number of times upon which
+ * we have to lookup, lock and open vcaches and dcaches
+ */
+
+static int
+afs_linux_readpages(struct file *fp, struct address_space *mapping,
+		    struct list_head *page_list, unsigned int num_pages)
+{
+    struct inode *inode = mapping->host;
+    struct vcache *avc = VTOAFS(inode);
+    struct dcache *tdc;
+    struct file *cacheFp = NULL;
+    int code;
+    unsigned int page_idx;
+    loff_t offset;
+    struct pagevec lrupv;
+    struct afs_pagecopy_task *task;
+
+#if defined(AFS_CACHE_BYPASS)
+    bypasscache = afs_linux_can_bypass(ip);
+
+    /* In the new incarnation of selective caching, a file's caching policy
+     * can change, eg because file size exceeds threshold, etc. */
+    trydo_cache_transition(avc, credp, bypasscache);
+
+    if (bypasscache)
+	return afs_linux_cache_bypass_read(ip, mapping, page_list, num_pages);
+#endif
+
+    AFS_GLOCK();
+    if ((code = afs_linux_VerifyVCache(avc, NULL))) {
+	AFS_GUNLOCK();
+	return code;
+    }
+
+    ObtainWriteLock(&avc->lock, 912);
+    AFS_GUNLOCK();
+
+    task = afs_pagecopy_init_task();
+
+    tdc = NULL;
+    pagevec_init(&lrupv, 0);
+    for (page_idx = 0; page_idx < num_pages; page_idx++) {
+	struct page *page = list_entry(page_list->prev, struct page, lru);
+	list_del(&page->lru);
+	offset = page_offset(page);
+
+	if (tdc && tdc->f.chunk != AFS_CHUNK(offset)) {
+	    AFS_GLOCK();
+	    ReleaseReadLock(&tdc->lock);
+	    afs_PutDCache(tdc);
+	    AFS_GUNLOCK();
+	    tdc = NULL;
+	    if (cacheFp)
+		filp_close(cacheFp, NULL);
+	}
+
+	if (!tdc) {
+	    AFS_GLOCK();
+	    if ((tdc = afs_FindDCache(avc, offset))) {
+		ObtainReadLock(&tdc->lock);
+		if (!hsame(avc->f.m.DataVersion, tdc->f.versionNo) ||
+		    (tdc->dflags & DFFetching)) {
+		    ReleaseReadLock(&tdc->lock);
+		    afs_PutDCache(tdc);
+		    tdc = NULL;
+		}
+	    }
+	    AFS_GUNLOCK();
+	    if (tdc)
+		cacheFp = afs_linux_raw_open(&tdc->f.inode, NULL);
+	}
+
+	if (tdc && !add_to_page_cache(page, mapping, page->index,
+				      GFP_KERNEL)) {
+	    page_cache_get(page);
+	    if (!pagevec_add(&lrupv, page))
+		__pagevec_lru_add_file(&lrupv);
+
+	    afs_linux_read_cache(cacheFp, page, tdc->f.chunk, &lrupv, task);
+	}
+	page_cache_release(page);
+    }
+    if (pagevec_count(&lrupv))
+       __pagevec_lru_add_file(&lrupv);
+
+    if (tdc)
+	filp_close(cacheFp, NULL);
+
+    afs_pagecopy_put_task(task);
+
+    AFS_GLOCK();
+    if (tdc) {
+	ReleaseReadLock(&tdc->lock);
+        afs_PutDCache(tdc);
+    }
+
+    ReleaseWriteLock(&avc->lock);
+    AFS_GUNLOCK();
+    return 0;
+}
 
 #if defined(AFS_LINUX24_ENV)
 static int
@@ -1964,7 +2276,7 @@ afs_linux_writepage_sync(struct inode *ip, struct page *pp,
 	if (!afs_InitReq(&treq, credp))
 	    code = afs_DoPartialWrite(vcp, &treq);
     }
-    code = code ? -code : count - tuio.uio_resid;
+    code = code ? afs_convert_code(code) : count - tuio.uio_resid;
 
     vcp->f.states &= ~CPageWrite;
     ReleaseWriteLock(&vcp->lock);
@@ -2023,10 +2335,12 @@ afs_linux_writepage(struct page *pp)
   do_it:
     status = afs_linux_writepage_sync(inode, pp, 0, offset);
     SetPageUptodate(pp);
+#if defined(AFS_LINUX26_ENV)
 #if defined(WRITEPAGE_ACTIVATE)
     if ( status != WRITEPAGE_ACTIVATE )
 #else
     if ( status != AOP_WRITEPAGE_ACTIVATE )
+#endif
 #endif
 	UnlockPage(pp);
     if (status == offset)
@@ -2078,7 +2392,7 @@ afs_linux_updatepage(struct file *fp, struct page *pp, unsigned long offset,
 	ReleaseWriteLock(&vcp->lock);
     }
 
-    code = code ? -code : count - tuio.uio_resid;
+    code = code ? afs_convert_code(code) : count - tuio.uio_resid;
     afs_Trace4(afs_iclSetp, CM_TRACE_UPDATEPAGE, ICL_TYPE_POINTER, vcp,
 	       ICL_TYPE_POINTER, pp, ICL_TYPE_INT32, page_count(pp),
 	       ICL_TYPE_INT32, code);
@@ -2117,7 +2431,7 @@ afs_linux_permission(struct inode *ip, int mode)
 
     AFS_GUNLOCK();
     crfree(credp);
-    return -code;
+    return afs_convert_code(code);
 }
 
 #if defined(AFS_LINUX24_ENV) && !defined(HAVE_WRITE_BEGIN)
@@ -2156,7 +2470,6 @@ afs_linux_write_end(struct file *file, struct address_space *mapping,
                                 struct page *page, void *fsdata)
 {
     int code;
-    pgoff_t index = pos >> PAGE_CACHE_SHIFT;
     unsigned from = pos & (PAGE_CACHE_SIZE - 1);
 
     code = afs_linux_writepage_sync(file->f_dentry->d_inode, page,
@@ -2205,9 +2518,7 @@ static struct inode_operations afs_file_iops = {
 #if defined(AFS_LINUX24_ENV)
 static struct address_space_operations afs_file_aops = {
   .readpage =		afs_linux_readpage,
-#if defined(AFS_CACHE_BYPASS) && LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,0)
-  .readpages =		afs_linux_readpages,
-#endif  
+  .readpages = 		afs_linux_readpages,
   .writepage =		afs_linux_writepage,
 #if defined (HAVE_WRITE_BEGIN)
   .write_begin =        afs_linux_write_begin,
