@@ -10,8 +10,9 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/bozo/bosserver.c,v 1.32.2.17 2009/03/16 17:52:48 shadow Exp $");
+#ifdef IGNORE_SOME_GCC_WARNINGS
+# pragma GCC diagnostic warning "-Wdeprecated-declarations"
+#endif
 
 #include <afs/stds.h>
 #include <sys/types.h>
@@ -41,7 +42,6 @@ RCSID
 #include "bosprototypes.h"
 #include <rx/rxkad.h>
 #include <rx/rxstat.h>
-#include <rx/rxstat_prototypes.h>
 #include <afs/keys.h>
 #include <afs/ktime.h>
 #include <afs/afsutil.h>
@@ -296,7 +296,6 @@ ReadBozoFile(char *aname)
 	    if (code < 0)
 		perror("bosconfig rename");
 	}
-#ifdef BOS_NEW_CONFIG
 	if (access(AFSDIR_SERVER_BOZCONFNEW_FILEPATH, 0) == 0) {
 	    code =
 		renamefile(AFSDIR_SERVER_BOZCONFNEW_FILEPATH,
@@ -304,7 +303,6 @@ ReadBozoFile(char *aname)
 	    if (code < 0)
 		perror("bosconfig rename");
 	}
-#endif
     }
 
     /* setup default times we want to do restarts */
@@ -728,6 +726,7 @@ main(int argc, char **argv, char **envp)
     char namebuf[AFSDIR_PATH_MAX];
     int rxMaxMTU = -1;
     afs_uint32 host = htonl(INADDR_ANY);
+    char *auditFileName = NULL;
 #ifndef AFS_NT40_ENV
     int nofork = 0;
     struct stat sb;
@@ -843,9 +842,15 @@ main(int argc, char **argv, char **envp)
 	    }
 	}
 	else if (strcmp(argv[code], "-auditlog") == 0) {
-	    char *fileName = argv[++code];
+	    auditFileName = argv[++code];
 
-            osi_audit_file(fileName);
+	} else if (strcmp(argv[code], "-audit-interface") == 0) {
+	    char *interface = argv[++code];
+
+	    if (osi_audit_interface(interface)) {
+		printf("Invalid audit interface '%s'\n", interface);
+		exit(1);
+	    }
 	}
 	else {
 
@@ -854,6 +859,7 @@ main(int argc, char **argv, char **envp)
 #ifndef AFS_NT40_ENV
 	    printf("Usage: bosserver [-noauth] [-log] "
 		   "[-auditlog <log path>] "
+		   "[-audit-interafce <file|sysvmq> (default is file)] "
 		   "[-rxmaxmtu <bytes>] [-rxbind] [-allow-dotted-principals]"
 		   "[-syslog[=FACILITY]] "
 		   "[-enable_peer_stats] [-enable_process_stats] "
@@ -861,6 +867,7 @@ main(int argc, char **argv, char **envp)
 #else
 	    printf("Usage: bosserver [-noauth] [-log] "
 		   "[-auditlog <log path>] "
+		   "[-audit-interafce <file|sysvmq> (default is file)] "
 		   "[-rxmaxmtu <bytes>] [-rxbind] [-allow-dotted-principals]"
 		   "[-enable_peer_stats] [-enable_process_stats] "
 		   "[-help]\n");
@@ -870,6 +877,9 @@ main(int argc, char **argv, char **envp)
 	    exit(0);
 	}
     }
+    if (auditFileName) {
+	osi_audit_file(auditFileName);
+    }
 
 #ifndef AFS_NT40_ENV
     if (geteuid() != 0) {
