@@ -14,27 +14,40 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/bucoord/dsstub.c,v 1.6 2003/07/15 23:14:47 shadow Exp $");
 
 #include <sys/types.h>
 #include <afs/cmd.h>
 #ifdef AFS_NT40_ENV
 #include <winsock2.h>
 #else
-#include <strings.h>
 #include <sys/socket.h>
 #include <netinet/in.h>
 #include <netdb.h>
 #endif
 #include <stdio.h>
+#include <string.h>
 #include <dirent.h>
 #include <afs/afsutil.h>
 #include <afs/budb.h>
 #include <afs/bubasics.h>
 #include <afs/volser.h>
+#include "bc.h"
+
+/* protos */
+
+static char * TapeName(register char *);
+static char * DumpName(register afs_int32 adumpID);
+static FILE * OpenDump(afs_int32 , char * );
+FILE * OpenTape(char * , char * );
+static afs_int32 ScanForChildren(afs_int32 );
+static afs_int32 DeleteDump(afs_int32 );
+char * tailCompPtr(char *);
+afs_int32 ScanDumpHdr(register FILE *, char *, char *, afs_int32 *, afs_int32 *,
+  afs_int32 *, afs_int32 *);
+afs_int32 ScanTapeVolume(FILE *, char *, afs_int32 *, char *, afs_int32 *, afs_int32 *,
+   afs_int32 *, afs_int32 *);
+afs_int32 ScanVolClone(FILE *, char *, afs_int32 *);
 
-#define	dprintf			/* debug */
 
 /* basic format of a tape file is a file, whose name is "T<tapename>.db", and
  * which contains the fields
@@ -53,13 +66,9 @@ RCSID
  * Note that dumpEndTime is stored and returned in the dump creation time field.
  */
 
-afs_int32 DeleteDump();
-afs_int32 ScanDumpHdr();
-
 /* return the tape file name corresponding to a particular tape */
-static char *
-TapeName(atapeName)
-     register char *atapeName;
+
+static char * TapeName(register char *atapeName)
 {
     static char tbuffer[AFSDIR_PATH_MAX];
 
@@ -72,9 +81,8 @@ TapeName(atapeName)
 }
 
 /* return the dump file name corresponding to a particular dump ID */
-static char *
-DumpName(adumpID)
-     register afs_int32 adumpID;
+
+static char * DumpName(register afs_int32 adumpID)
 {
     static char tbuffer[AFSDIR_PATH_MAX];
     char buf[AFSDIR_PATH_MAX];
@@ -86,10 +94,7 @@ DumpName(adumpID)
     return tbuffer;
 }
 
-static FILE *
-OpenDump(adumpID, awrite)
-     char *awrite;
-     afs_int32 adumpID;
+static FILE * OpenDump(afs_int32 adumpID, char * awrite)
 {
     register char *tp;
     register FILE *tfile;
@@ -104,10 +109,7 @@ OpenDump(adumpID, awrite)
  * 	non-static for recoverDB
  */
 
-FILE *
-OpenTape(atapeName, awrite)
-     char *awrite;
-     char *atapeName;
+FILE * OpenTape(char * atapeName, char * awrite)
 {
     register char *tp;
     register FILE *tfile;
@@ -117,9 +119,8 @@ OpenTape(atapeName, awrite)
 }
 
 /* scan for, and delete, all dumps whose parent dump ID is aparentID */
-static afs_int32
-ScanForChildren(aparentID)
-     afs_int32 aparentID;
+
+static afs_int32 ScanForChildren(afs_int32 aparentID)
 {
     DIR *tdir;
     register struct dirent *tde;
@@ -135,7 +136,7 @@ ScanForChildren(aparentID)
 	return -1;
 
     for (tde = readdir(tdir); tde; tde = readdir(tdir)) {
-	code = sscanf(tde->d_name, "D%ld.db", &dumpID);
+	code = sscanf(tde->d_name, "D%ld.db", (long int *) &dumpID);
 	if (code != 1)
 	    continue;
 
@@ -162,9 +163,7 @@ ScanForChildren(aparentID)
     return 0;
 }
 
-static afs_int32
-DeleteDump(adumpID)
-     afs_int32 adumpID;
+static afs_int32 DeleteDump(afs_int32 adumpID)
 {
     register char *tp;
     register afs_int32 code;
@@ -176,9 +175,8 @@ DeleteDump(adumpID)
     return code;
 }
 
-static afs_int32
-DeleteTape(atapeName)
-     char *atapeName;
+#if 0
+static afs_int32 DeleteTape(char * atapeName)
 {
     register char *tp;
     register afs_int32 code;
@@ -186,6 +184,7 @@ DeleteTape(atapeName)
     code = unlink(tp);
     return code;
 }
+#endif
 
 /* tailCompPtr
  *	name is a pathname style name, determine trailing name and return
@@ -193,8 +192,7 @@ DeleteTape(atapeName)
  */
 
 char *
-tailCompPtr(pathNamePtr)
-     char *pathNamePtr;
+tailCompPtr(char *pathNamePtr)
 {
     char *ptr;
     ptr = strrchr(pathNamePtr, '/');
@@ -222,14 +220,7 @@ tailCompPtr(pathNamePtr)
  *	alevel - level of dump (0 = full, 1+ are incrementals)
  */
 afs_int32
-ScanDumpHdr(afile, aname, dumpName, aparent, aincTime, acreateTime, alevel)
-     register FILE *afile;
-     char *aname;
-     char *dumpName;
-     afs_int32 *aparent;
-     afs_int32 *acreateTime;
-     afs_int32 *aincTime;
-     afs_int32 *alevel;
+ScanDumpHdr(register FILE *afile, char *aname, char *dumpName, afs_int32 *aparent, afs_int32 *aincTime, afs_int32 *acreateTime, afs_int32 *alevel)
 {
     char tbuffer[256];
     char *tp;
@@ -241,7 +232,8 @@ ScanDumpHdr(afile, aname, dumpName, aparent, aincTime, acreateTime, alevel)
 	return -1;
     code =
 	sscanf(tbuffer, "%d %d %s %s %ld %ld %ld %ld", &dbmagic, &dbversion,
-	       aname, dumpName, aparent, aincTime, acreateTime, alevel);
+	       aname, dumpName, (long int *) aparent, (long int *) aincTime, 
+	       (long int *) acreateTime, (long int *) alevel);
     if (code != 8)
 	return -1;
 
@@ -252,13 +244,9 @@ ScanDumpHdr(afile, aname, dumpName, aparent, aincTime, acreateTime, alevel)
     return 0;
 }
 
+#if 0
 /* scan a tape header out of a tape file, leaving the file ptr positioned just past the header */
-static afs_int32
-ScanTapeHdr(afile, adumpID, aseq, adamage)
-     register FILE *afile;
-     afs_int32 *adumpID;
-     afs_int32 *aseq;
-     afs_int32 *adamage;
+static afs_int32 ScanTapeHdr(register FILE *afile, afs_int32 *adumpID, afs_int32 *aseq, afs_int32 *adamage)
 {
     char tbuffer[256];
     char *tp;
@@ -267,11 +255,13 @@ ScanTapeHdr(afile, adumpID, aseq, adamage)
     tp = fgets(tbuffer, sizeof(tbuffer), afile);
     if (!tp)
 	return -1;
-    code = sscanf(tbuffer, "%ld %ld %ld", adumpID, aseq, adamage);
+    code = sscanf(tbuffer, "%ld %ld %ld", (long int *)adumpID, 
+		  (long int *)aseq, (long int *)adamage);
     if (code != 3)
 	return -1;
     return 0;
 }
+#endif
 
 /* ScanTapeVolume
  *	scan a tape volume record from a dump file, leaving the file ptr
@@ -282,14 +272,7 @@ ScanTapeHdr(afile, adumpID, aseq, adamage)
  *	-1 for error
  */
 
-afs_int32
-ScanTapeVolume(afile, avolName, avolID, atapeName, apos, aseq, alastp,
-	       cloneTime)
-     FILE *afile;
-     char *avolName;
-     afs_int32 *avolID;
-     char *atapeName;
-     afs_int32 *apos, *aseq, *alastp, *cloneTime;
+afs_int32 ScanTapeVolume(FILE *afile, char *avolName, afs_int32 *avolID, char *atapeName, afs_int32 *apos, afs_int32 *aseq, afs_int32 *alastp, afs_int32 *cloneTime)
 {
     char tbuffer[256];
     register afs_int32 code;
@@ -303,8 +286,10 @@ ScanTapeVolume(afile, avolName, avolID, atapeName, apos, aseq, alastp,
 	    return 1;		/* eof */
     }
     code =
-	sscanf(tbuffer, "%s %ld %s %ld %ld %ld %ld", avolName, avolID,
-	       atapeName, apos, aseq, alastp, cloneTime);
+	sscanf(tbuffer, "%s %ld %s %ld %ld %ld %ld", avolName, 
+	       (long int *) avolID, atapeName, (long int *)apos, 
+	       (long int *) aseq, (long int *) alastp, 
+	       (long int *) cloneTime);
     if (code != 7)
 	return -1;		/* bad input line */
     return 0;
@@ -318,11 +303,7 @@ ScanTapeVolume(afile, avolName, avolID, atapeName, apos, aseq, alastp,
  *	-1 - volume with volName not found
  */
 
-afs_int32
-ScanVolClone(tdump, volName, cloneTime)
-     FILE *tdump;
-     char *volName;
-     afs_int32 *cloneTime;
+afs_int32 ScanVolClone(FILE *tdump, char *volName, afs_int32 *cloneTime)
 {
     char avolName[256], atapeName[256];
     afs_int32 retval, avolID, apos, aseq, alastp;
@@ -340,11 +321,9 @@ ScanVolClone(tdump, volName, cloneTime)
     return (-1);
 }
 
+#if 0
 /* seek a dump file (after a header scan has been done) to position apos */
-static
-SeekDump(afile, apos)
-     register FILE *afile;
-     afs_int32 apos;
+static int SeekDump(register FILE *afile, afs_int32 apos)
 {
     register afs_int32 i;
     register char *tp;
@@ -360,3 +339,4 @@ SeekDump(afile, apos)
     }
     return 0;
 }
+#endif
