@@ -10,10 +10,9 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/butc/lwps.c,v 1.14 2005/07/11 03:22:20 shadow Exp $");
 
 #include <sys/types.h>
+#include <string.h>
 #ifdef AFS_NT40_ENV
 #include <winsock2.h>
 #include <conio.h>
@@ -32,12 +31,14 @@ RCSID
 #include <afs/tcdata.h>
 #include <afs/bubasics.h>	/* PA */
 #include <afs/budb_client.h>
+#include <afs/bucoord_prototypes.h>
 #include <afs/volser.h>
 #include <afs/com_err.h>
 #include "error_macros.h"
 #include <afs/afsutil.h>
 #include <errno.h>
 #include "butc_xbsa.h"
+#include "butc_internal.h"
 
 /* GLOBAL CONFIGURATION PARAMETERS */
 extern int queryoperator;
@@ -45,7 +46,7 @@ extern int tapemounted;
 extern char *opencallout;
 extern char *closecallout;
 extern char *whoami;
-extern char *extractDumpName();
+extern char *extractDumpName(char *);
 extern int BufferSize;		/* Size in B stored for header info */
 FILE *restoretofilefd;
 #ifdef xbsa
@@ -123,21 +124,25 @@ struct timeval tp;
 struct timezone tzp;
 
 /* forward declaration */
-afs_int32 readVolumeHeader( /*char *buffer,afs_int32 bufloc,(struct volumeHeader *)vhptr */ );
+afs_int32 readVolumeHeader(char *, afs_int32, struct volumeHeader *);
+int FindVolTrailer(char *, afs_int32, afs_int32 *, struct volumeHeader *);
+int FindVolTrailer2(char *, afs_int32, afs_int32 *, char *, afs_int32,
+		    afs_int32 *, struct volumeHeader *);
+int SkipVolume(struct tc_restoreDesc *, afs_int32, afs_int32, afs_int32,
+	       afs_int32);
+
+
 
 /* The on-disk volume header or trailer can differ in size from platform to platform */
 static struct TapeBlock tapeBlock;
 char tapeVolumeHT[sizeof(struct volumeHeader) + 2 * sizeof(char)];
 
 void
-PrintLog(log, error1, error2, str, a, b, c, d, e, f, g, h, i, j)
-     FILE *log;
-     afs_int32 error1, error2;
-     char *str, *a, *b, *c, *d, *e, *f, *g, *h, *i, *j;
+PrintLogStr(FILE *log, afs_int32 error1, afs_int32 error2, char *str)
 {
     char *err1, *err2;
 
-    fprintf(log, str, a, b, c, d, e, f, g, h, i, j);
+    fprintf(log, str);
     if (error1) {
 	err2 = "vols";
 	switch (error1) {
@@ -175,8 +180,8 @@ PrintLog(log, error1, error2, str, a, b, c, d, e, f, g, h, i, j)
 	    err1 = "Volume has moved to another server";
 	    break;
 	default:
-	    err1 = (char *)error_message(error1);
-	    err2 = (char *)error_table_name(error1);
+	    err1 = (char *)afs_error_message(error1);
+	    err2 = (char *)afs_error_table_name(error1);
 	    break;
 	}
 	if (error1 == -1)
@@ -184,17 +189,15 @@ PrintLog(log, error1, error2, str, a, b, c, d, e, f, g, h, i, j)
 	else
 	    fprintf(log, "     %s: %s", err2, err1);
 	if (error2)
-	    fprintf(log, ": %s", error_message(error2));
+	    fprintf(log, ": %s", afs_error_message(error2));
 	fprintf(log, "\n");
     }
     fflush(log);
 }
 
 void
-TapeLog(debug, task, error1, error2, str, a, b, c, d, e, f, g, h, i, j)
-     int debug;
-     afs_int32 task, error1, error2;
-     char *str, *a, *b, *c, *d, *e, *f, *g, *h, *i, *j;
+TapeLogStr(int debug, afs_int32 task, afs_int32 error1, afs_int32 error2,
+	   char *str)
 {
     time_t now;
     char tbuffer[32], *timestr;
@@ -206,35 +209,51 @@ TapeLog(debug, task, error1, error2, str, a, b, c, d, e, f, g, h, i, j)
     fprintf(logIO, "%s: ", timestr);
     if (task)
 	fprintf(logIO, "Task %u: ", task);
-    PrintLog(logIO, error1, error2, str, a, b, c, d, e, f, g, h, i, j);
+    PrintLogStr(logIO, error1, error2, str);
 
     if (lastPass && lastLogIO) {
 	fprintf(lastLogIO, "%s: ", timestr);
 	if (task)
 	    fprintf(lastLogIO, "Task %u: ", task);
-	PrintLog(lastLogIO, error1, error2, str, a, b, c, d, e, f, g, h, i,
-		 j);
+	PrintLogStr(lastLogIO, error1, error2, str);
     }
 
     /* Now print to the screen if debug level requires */
     if (debug <= debugLevel)
-	PrintLog(stdout, error1, error2, str, a, b, c, d, e, f, g, h, i, j);
+	PrintLogStr(stdout, error1, error2, str);
 }
 
 void
-TLog(task, str, a, b, c, d, e, f, g, h, i, j)
-     afs_int32 task;
-     char *str, *a, *b, *c, *d, *e, *f, *g, *h, *i, *j;
+TapeLog(int debug, afs_int32 task, afs_int32 error1, afs_int32 error2,
+	char *fmt, ...)
 {
-    /* Sends message to TapeLog and stdout */
-    TapeLog(0, task, 0, 0, str, a, b, c, d, e, f, g, h, i, j);
+    char tmp[1024];
+    va_list ap;
+
+    va_start(ap, fmt);
+    afs_vsnprintf(tmp, sizeof(tmp), fmt, ap);
+    va_end(ap);
+
+    TapeLogStr(debug, task, error1, error2, tmp);
 }
 
 void
-ErrorLog(debug, task, error1, error2, str, a, b, c, d, e, f, g, h, i, j)
-     int debug;
-     afs_int32 task, error1, error2;
-     char *str, *a, *b, *c, *d, *e, *f, *g, *h, *i, *j;
+TLog(afs_int32 task, char *fmt, ...)
+{
+    char tmp[1024];
+    va_list ap;
+
+    va_start(ap, fmt);
+    afs_vsnprintf(tmp, sizeof(tmp), fmt, ap);
+    va_end(ap);
+
+    /* Sends message to TapeLog and stdout */
+    TapeLogStr(0, task, 0, 0, tmp);
+}
+
+void
+ErrorLogStr(int debug, afs_int32 task, afs_int32 error1, afs_int32 error2,
+	    char *errStr)
 {
     time_t now;
     char tbuffer[32], *timestr;
@@ -247,24 +266,43 @@ ErrorLog(debug, task, error1, error2, str, a, b, c, d, e, f, g, h, i, j)
     /* Print the time and task number */
     if (task)
 	fprintf(ErrorlogIO, "Task %u: ", task);
-    PrintLog(ErrorlogIO, error1, error2, str, a, b, c, d, e, f, g, h, i, j);
 
-    TapeLog(debug, task, error1, error2, str, a, b, c, d, e, f, g, h, i, j);
+    PrintLogStr(ErrorlogIO, error1, error2, errStr);
+    TapeLogStr(debug, task, error1, error2, errStr);
 }
 
 void
-ELog(task, str, a, b, c, d, e, f, g, h, i, j)
-     afs_int32 task;
-     char *str, *a, *b, *c, *d, *e, *f, *g, *h, *i, *j;
+ErrorLog(int debug, afs_int32 task, afs_int32 error1, afs_int32 error2,
+	 char *fmt, ...)
 {
+    char tmp[1024];
+    va_list ap;
+
+    va_start(ap, fmt);
+    afs_vsnprintf(tmp, sizeof(tmp), fmt, ap);
+    va_end(ap);
+
+    ErrorLogStr(debug, task, error1, error2, tmp);
+
+}
+
+void
+ELog(afs_int32 task, char *fmt, ...)
+{
+    char tmp[1024];
+    va_list ap;
+
+    va_start(ap, fmt);
+    afs_vsnprintf(tmp, sizeof(tmp), fmt, ap);
+    va_end(ap);
+
     /* Sends message to ErrorLog, TapeLog and stdout */
-    ErrorLog(0, task, 0, 0, str, a, b, c, d, e, f, g, h, i, j);
+    ErrorLog(0, task, 0, 0, tmp);
 }
 
 /* first proc called by anybody who intends to use the device */
 void
-EnterDeviceQueue(devLatch)
-     struct deviceSyncNode *devLatch;
+EnterDeviceQueue(struct deviceSyncNode *devLatch)
 {
     ObtainWriteLock(&(devLatch->lock));
     devLatch->flags = TC_DEVICEINUSE;
@@ -272,8 +310,7 @@ EnterDeviceQueue(devLatch)
 
 /* last proc called by anybody finishing using the device */
 void
-LeaveDeviceQueue(devLatch)
-     struct deviceSyncNode *devLatch;
+LeaveDeviceQueue(struct deviceSyncNode *devLatch)
 {
     devLatch->flags = 0;
     ReleaseWriteLock(&(devLatch->lock));
@@ -396,15 +433,16 @@ GetResponseKey(int seconds, char *key)
 #endif
     return rc;
 }
-#endif /* AFS_PTHREAD_ENV
-        * 
-        * /* FFlushInput
-        * *     flush all input
-        * * notes:
-        * *     only external clients are in recoverDb.c. Was static. PA
-        */
+#endif /* AFS_PTHREAD_ENV */
+
+/*
+ * FFlushInput
+ *     flush all input
+ * notes:
+ *     only external clients are in recoverDb.c. Was static. PA
+ */
 void
-FFlushInput()
+FFlushInput(void)
 {
     int w;
 
@@ -430,15 +468,9 @@ FFlushInput()
 }
 
 int
-callOutRoutine(taskId, tapePath, flag, name, dbDumpId, tapecount)
-     afs_int32 taskId;
-     char *tapePath;
-     int flag;
-     char *name;
-     afs_uint32 dbDumpId;
-     int tapecount;
+callOutRoutine(afs_int32 taskId, char *tapePath, int flag, char *name,
+	       afs_uint32 dbDumpId, int tapecount)
 {
-    afs_int32 code = 0;
     int pid;
 
     char StapePath[256];
@@ -546,9 +578,8 @@ callOutRoutine(taskId, tapePath, flag, name, dbDumpId, tapecount)
  *     Regardless of error, the closecallout routine will be called
  *     (unless a tape is not mounted in the first place).
  */
-unmountTape(taskId, tapeInfoPtr)
-     afs_int32 taskId;
-     struct butm_tapeInfo *tapeInfoPtr;
+void
+unmountTape(afs_int32 taskId, struct butm_tapeInfo *tapeInfoPtr)
 {
     afs_int32 code;
     int cpid, status, rcpid;
@@ -573,7 +604,7 @@ unmountTape(taskId, tapeInfoPtr)
 	    }
 	    if (rcpid == -1 && errno != EINTR) {
 		tapemounted = 0;
-		com_err(whoami, errno,
+		afs_com_err(whoami, errno,
 			"Error waiting for callout script to terminate.");
 		break;
 	    }
@@ -602,9 +633,7 @@ unmountTape(taskId, tapeInfoPtr)
  */
 
 void static
-PrintPrompt(flag, name, dumpid)
-     int flag;
-     char *name;
+PrintPrompt(int flag, char *name, int dumpid)
 {
     char tapename[BU_MAXTAPELEN + 32];
     char *dn;
@@ -678,12 +707,8 @@ PrintPrompt(flag, name, dumpid)
  *	only external clients are in recoverDb.c. Was static PA
  */
 afs_int32
-PromptForTape(flag, name, dbDumpId, taskId, tapecount)
-     int flag;
-     char *name;
-     afs_uint32 dbDumpId;	/* Specific dump ID - If non-zero */
-     afs_uint32 taskId;
-     int tapecount;
+PromptForTape(int flag, char *name, afs_uint32 dbDumpId, afs_uint32 taskId,
+	      int tapecount)
 {
     register afs_int32 code = 0;
     afs_int32 wcode;
@@ -737,7 +762,7 @@ PromptForTape(flag, name, dbDumpId, taskId, tapecount)
 	    }
 	    /* if waitpid experienced an error, we prompt */
 	    if (rcpid == -1 && errno != EINTR) {
-		com_err(whoami, errno,
+		afs_com_err(whoami, errno,
 			"Error waiting for callout script to terminate.");
 		TLog(taskId,
 		     "Can't get exit status from callout script. will prompt\n");
@@ -861,8 +886,8 @@ PromptForTape(flag, name, dbDumpId, taskId, tapecount)
  */
 
 afs_int32
-VolHeaderToHost(hostVolHeader, tapeVolHeader)
-     struct volumeHeader *hostVolHeader, *tapeVolHeader;
+VolHeaderToHost(struct volumeHeader *hostVolHeader,
+		struct volumeHeader *tapeVolHeader)
 {
     switch (ntohl(tapeVolHeader->versionflags)) {
     case TAPE_VERSION_0:
@@ -903,10 +928,9 @@ VolHeaderToHost(hostVolHeader, tapeVolHeader)
 }
 
 afs_int32
-ReadVolHeader(taskId, tapeInfoPtr, volHeaderPtr)
-     afs_int32 taskId;
-     struct butm_tapeInfo *tapeInfoPtr;
-     struct volumeHeader *volHeaderPtr;
+ReadVolHeader(afs_int32 taskId,
+	      struct butm_tapeInfo *tapeInfoPtr,
+	      struct volumeHeader *volHeaderPtr)
 {
     afs_int32 code = 0;
     afs_int32 nbytes;
@@ -940,12 +964,8 @@ ReadVolHeader(taskId, tapeInfoPtr, volHeaderPtr)
 }
 
 afs_int32 static
-GetVolumeHead(taskId, tapeInfoPtr, position, volName, volId)
-     afs_int32 taskId;
-     struct butm_tapeInfo *tapeInfoPtr;
-     afs_int32 position;
-     char *volName;
-     afs_int32 volId;
+GetVolumeHead(afs_int32 taskId, struct butm_tapeInfo *tapeInfoPtr,
+	      afs_int32 position, char *volName, afs_int32 volId)
 {
     afs_int32 code = 0;
     struct volumeHeader tapeVolHeader;
@@ -1014,12 +1034,8 @@ GetVolumeHead(taskId, tapeInfoPtr, position, volName, volId)
 }
 
 afs_int32
-GetRestoreTape(taskId, tapeInfoPtr, tname, tapeID, prompt)
-     afs_int32 taskId;
-     struct butm_tapeInfo *tapeInfoPtr;
-     char *tname;
-     afs_int32 tapeID;
-     int prompt;
+GetRestoreTape(afs_int32 taskId, struct butm_tapeInfo *tapeInfoPtr,
+	       char *tname, afs_int32 tapeID, int prompt)
 {
     struct butm_tapeLabel tapeLabel;
     afs_int32 code = 0, rc;
@@ -1084,9 +1100,7 @@ GetRestoreTape(taskId, tapeInfoPtr, tname, tapeID, prompt)
 }
 
 afs_int32
-xbsaRestoreVolumeData(call, rparamsPtr)
-     register struct rx_call *call;
-     struct restoreParams *rparamsPtr;
+xbsaRestoreVolumeData(struct rx_call *call, struct restoreParams *rparamsPtr)
 {
     afs_int32 code = 0;
 #ifdef xbsa
@@ -1237,13 +1251,11 @@ xbsaRestoreVolumeData(call, rparamsPtr)
  */
 
 afs_int32
-restoreVolumeData(call, rparamsPtr)
-     register struct rx_call *call;
-     struct restoreParams *rparamsPtr;
+restoreVolumeData(struct rx_call *call, struct restoreParams *rparamsPtr)
 {
     afs_int32 curChunk;
     afs_uint32 totalWritten = 0;
-    afs_int32 code;
+    afs_int32 code = 0;
     afs_int32 headBytes, tailBytes, w;
     afs_int32 taskId;
     afs_int32 nbytes;		/* # bytes data in last tape block read */
@@ -1426,10 +1438,9 @@ restoreVolumeData(call, rparamsPtr)
 /* SkipTape
  *    Find all the volumes on a specific tape and mark them to skip.
  */
-SkipTape(Restore, size, index, tapename, tapeid, taskid)
-     struct tc_restoreDesc *Restore;
-     afs_int32 size, index, tapeid, taskid;
-     char *tapename;
+int
+SkipTape(struct tc_restoreDesc *Restore, afs_int32 size, afs_int32 index,
+	 char *tapename, afs_int32 tapeid, afs_int32 taskid)
 {
     afs_int32 i, tid;
 
@@ -1449,9 +1460,9 @@ SkipTape(Restore, size, index, tapename, tapeid, taskid)
 /* SkipVolume
  *    Find all the entries for a volume and mark them to skip.
  */
-SkipVolume(Restore, size, index, volid, taskid)
-     struct tc_restoreDesc *Restore;
-     afs_int32 size, index, volid, taskid;
+int
+SkipVolume(struct tc_restoreDesc *Restore, afs_int32 size, afs_int32 index,
+	   afs_int32 volid, afs_int32 taskid)
 {
     afs_int32 i;
     int report = 1;
@@ -1472,10 +1483,9 @@ SkipVolume(Restore, size, index, volid, taskid)
     return 0;
 }
 
-xbsaRestoreVolume(taskId, restoreInfo, rparamsPtr)
-     afs_uint32 taskId;
-     struct tc_restoreDesc *restoreInfo;
-     struct restoreParams *rparamsPtr;
+int
+xbsaRestoreVolume(afs_uint32 taskId, struct tc_restoreDesc *restoreInfo,
+		  struct restoreParams *rparamsPtr)
 {
     afs_int32 code = 0;
 #ifdef xbsa
@@ -1664,10 +1674,9 @@ xbsaRestoreVolume(taskId, restoreInfo, rparamsPtr)
     return (code);
 }
 
-restoreVolume(taskId, restoreInfo, rparamsPtr)
-     afs_uint32 taskId;
-     struct tc_restoreDesc *restoreInfo;
-     struct restoreParams *rparamsPtr;
+int
+restoreVolume(afs_uint32 taskId, struct tc_restoreDesc *restoreInfo,
+	      struct restoreParams *rparamsPtr)
 {
     afs_int32 code = 0, rc;
     afs_int32 newServer, newPart, newVolId;
@@ -1741,9 +1750,10 @@ restoreVolume(taskId, restoreInfo, rparamsPtr)
  *	created as a LWP by the server stub, <newNode> is a pointer to all
  *	the parameters Restorer needs
  */
-Restorer(newNode)
-     struct dumpNode *newNode;
-{
+void *
+Restorer(void *param) {
+    struct dumpNode *newNode = (struct dumpNode *) param;
+
     afs_int32 code = 0, tcode;
     afs_uint32 taskId;
     char *newVolName;
@@ -1917,15 +1927,14 @@ Restorer(newNode)
 
     FreeNode(taskId);
     LeaveDeviceQueue(deviceLatch);
-    return (code);
+    return (void *)(intptr_t)(code);
 }
 
 /* this is just scaffolding, creates new tape label with name <tapeName> */
 
-GetNewLabel(tapeInfoPtr, pName, AFSName, tapeLabel)
-     struct butm_tapeInfo *tapeInfoPtr;
-     char *pName, *AFSName;
-     struct butm_tapeLabel *tapeLabel;
+void
+GetNewLabel(struct butm_tapeInfo *tapeInfoPtr, char *pName, char *AFSName,
+	    struct butm_tapeLabel *tapeLabel)
 {
     struct timeval tp;
     struct timezone tzp;
@@ -1957,13 +1966,11 @@ GetNewLabel(tapeInfoPtr, pName, AFSName, tapeLabel)
     strcpy(tapeLabel->creator.cell, globalCellName);
 }
 
-/* extracts trailer out of buffer, nbytes is set to total data in buffer - trailer size */
+/* extracts trailer out of buffer, nbytes is set to total data in
+ * buffer - trailer size */
 afs_int32
-ExtractTrailer(buffer, size, nbytes, volTrailerPtr)
-     char *buffer;
-     afs_int32 *nbytes;
-     afs_int32 size;
-     struct volumeHeader *volTrailerPtr;
+ExtractTrailer(char *buffer, afs_int32 size, afs_int32 *nbytes,
+	       struct volumeHeader *volTrailerPtr)
 {
     afs_int32 code = 0;
     afs_int32 startPos;
@@ -1991,11 +1998,8 @@ ExtractTrailer(buffer, size, nbytes, volTrailerPtr)
 }
 
 int
-FindVolTrailer(buffer, size, dSize, volTrailerPtr)
-     char *buffer;
-     afs_int32 size;
-     struct volumeHeader *volTrailerPtr;
-     afs_int32 *dSize;		/* dataSize */
+FindVolTrailer(char *buffer, afs_int32 size, afs_int32 *dSize,
+	       struct volumeHeader *volTrailerPtr)
 {
     afs_int32 offset, s;
     int found;
@@ -2015,15 +2019,9 @@ FindVolTrailer(buffer, size, dSize, volTrailerPtr)
 }
 
 int
-FindVolTrailer2(buffera, sizea, dataSizea, bufferb, sizeb, dataSizeb,
-		volTrailerPtr)
-     char *buffera;
-     afs_int32 sizea;
-     afs_int32 *dataSizea;
-     char *bufferb;
-     afs_int32 sizeb;
-     afs_int32 *dataSizeb;
-     struct volumeHeader *volTrailerPtr;
+FindVolTrailer2(char *buffera, afs_int32 sizea, afs_int32 *dataSizea,
+		char *bufferb, afs_int32 sizeb, afs_int32 *dataSizeb,
+		struct volumeHeader *volTrailerPtr)
 {
     afs_int32 offset, s;
     afs_int32 headB, tailB;
@@ -2068,11 +2066,9 @@ FindVolTrailer2(buffera, sizea, dataSizea, bufferb, sizeb, dataSizeb,
     return found;
 }
 
-/* Returns true or false depending on whether the tape is expired or not */
 
 Date
-ExpirationDate(dumpid)
-     afs_int32 dumpid;
+ExpirationDate(afs_int32 dumpid)
 {
     afs_int32 code;
     Date expiration = 0;
@@ -2082,9 +2078,10 @@ ExpirationDate(dumpid)
 
     if (dumpid) {
 	/*
-	 * Get the expiration date from DB if its there. The expiration of any tape
-	 * will be the most future expiration of any dump in the set. Can't use
-	 * bcdb_FindTape because dumpid here pertains to the initial dump id.
+	 * Get the expiration date from DB if its there. The expiration of
+	 * any tape will be the most future expiration of any dump in the
+	 * set. Can't use bcdb_FindTape because dumpid here pertains to the
+	 * initial dump id.
 	 */
 	code = bcdb_FindLastTape(dumpid, &dumpEntry, &tapeEntry, &volEntry);
 	if (!code)
@@ -2093,9 +2090,10 @@ ExpirationDate(dumpid)
     return (expiration);
 }
 
+/* Returns true or false depending on whether the tape is expired or not */
+
 int
-tapeExpired(tapeLabelPtr)
-     struct butm_tapeLabel *tapeLabelPtr;
+tapeExpired(struct butm_tapeLabel *tapeLabelPtr)
 {
     Date expiration;
     struct timeval tp;
@@ -2117,10 +2115,10 @@ tapeExpired(tapeLabelPtr)
  *	and the dump path.
  */
 
-updateTapeLabel(labelIfPtr, tapeInfoPtr, newLabelPtr)
-     struct labelTapeIf *labelIfPtr;
-     struct butm_tapeInfo *tapeInfoPtr;
-     struct butm_tapeLabel *newLabelPtr;
+int
+updateTapeLabel(struct labelTapeIf *labelIfPtr,
+		struct butm_tapeInfo *tapeInfoPtr,
+		struct butm_tapeLabel *newLabelPtr)
 {
     struct butm_tapeLabel oldLabel;
     afs_int32 i, code = 0;
@@ -2223,9 +2221,11 @@ updateTapeLabel(labelIfPtr, tapeInfoPtr, newLabelPtr)
  *	specified by <label>
  */
 
-Labeller(labelIfPtr)
-     struct labelTapeIf *labelIfPtr;
+void *
+Labeller(void *param)
 {
+    struct labelTapeIf *labelIfPtr = (struct labelTapeIf *)param;
+
     struct tc_tapeLabel *label = &labelIfPtr->label;
 
     struct butm_tapeLabel newTapeLabel;
@@ -2276,15 +2276,15 @@ Labeller(labelIfPtr)
 
     free(labelIfPtr);
     LeaveDeviceQueue(deviceLatch);
-    return (code);
+    return (void *)(intptr_t)(code);
 }
 
 /* PrintTapeLabel
  *	print out the tape label.
  */
 
-PrintTapeLabel(labelptr)
-     struct butm_tapeLabel *labelptr;
+void
+PrintTapeLabel(struct butm_tapeLabel *labelptr)
 {
     char tapeName[BU_MAXTAPELEN + 32];
     time_t t;
@@ -2318,8 +2318,8 @@ PrintTapeLabel(labelptr)
  *	back only selected fields.
  */
 
-ReadLabel(label)
-     struct tc_tapeLabel *label;
+int
+ReadLabel(struct tc_tapeLabel *label)
 {
     struct butm_tapeLabel newTapeLabel;
     struct butm_tapeInfo tapeInfo;
@@ -2408,14 +2408,9 @@ ReadLabel(label)
    into consideration, different word alignment rules.
 */
 afs_int32
-readVolumeHeader(buffer, bufloc, header)
-     /*in */
-     char *buffer;		/* buffer to read header from */
-				/*in */ afs_int32 bufloc;
-				/* header's location in buffer */
-						/*out */ struct volumeHeader *header;
-						/* header structure */
-
+readVolumeHeader(char *buffer,		/* in - buffer to read header from */
+		 afs_int32 bufloc,      /* in - header's location in buffer */
+		 struct volumeHeader *header) /* out -header structure */
 {
     struct volumeHeader vhptr, *tempvhptr;
     afs_int32 firstSplice = (afs_int32) ((char*)& vhptr.pad - (char*) & vhptr);
