@@ -10,8 +10,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/cmd/cmd.c,v 1.12.4.3 2008/01/13 15:35:41 jaltman Exp $");
 
 #include <sys/types.h>
 #include <ctype.h>
@@ -234,7 +232,7 @@ PrintFlagHelp(register struct cmd_syndesc *as)
 {
     register int i;
     register struct cmd_parmdesc *tp;
-    size_t flag_width;
+    int flag_width;
     char *flag_prefix;
 
     /* find flag name length */
