@@ -16,8 +16,8 @@
 #include <afs/param.h>
 #endif
 
-RCSID
-    ("$Header: /cvs/openafs/src/kauth/authclient.c,v 1.18.8.2 2006/09/21 11:41:45 shadow Exp $");
+
+#define UBIK_LEGACY_CALLITER 1
 
 #if defined(UKERNEL)
 #include "afs/sysincludes.h"
@@ -25,11 +25,12 @@ RCSID
 #include "afs_usrops.h"
 #include "afs/stds.h"
 #include "afs/pthread_glock.h"
+#include "des.h"
+#include "des_prototypes.h"
 #include "rx/rxkad.h"
 #include "afs/cellconfig.h"
 #include "ubik.h"
 #include "afs/auth.h"
-#include "des/des.h"
 #include "afs/afsutil.h"
 
 #include "afs/kauth.h"
@@ -46,18 +47,14 @@ RCSID
 #include <sys/socket.h>
 #include <netinet/in.h>
 #endif
-#ifdef HAVE_STRING_H
 #include <string.h>
-#else
-#ifdef HAVE_STRINGS_H
-#include <strings.h>
-#endif
-#endif
+#include <stdio.h>
+#include <des.h>
+#include <des_prototypes.h>
 #include <rx/rxkad.h>
 #include <afs/cellconfig.h>
 #include <ubik.h>
 #include <afs/auth.h>
-#include <des.h>
 #include <afs/afsutil.h>
 #include "kauth.h"
 #include "kautils.h"
@@ -400,21 +397,26 @@ CheckTicketAnswer(ka_BBS * oanswer, afs_int32 challenge,
 	if ((field) && strcmp (field, strings)) return KABADPROTOCOL;\
 	strings += len+1
 
+#define chknostr() \
+	len = strlen(strings); \
+	if (len > MAXKTCNAMELEN) return KABADPROTOCOL; \
+	strings += len+1
+
 	if (caller) {
 	    chkstr(caller->name);
 	    chkstr(caller->instance);
 	    chkstr(caller->cell);
 	} else {
-	    chkstr(0);
-	    chkstr(0);
-	    chkstr(0);
+	    chknostr();
+	    chknostr();
+	    chknostr();
 	}
 	if (server) {
 	    chkstr(server->name);
 	    chkstr(server->instance);
 	} else {
-	    chkstr(0);
-	    chkstr(0);
+	    chknostr();
+	    chknostr();
 	}
 
 	if (oanswer->SeqLen -
@@ -529,7 +531,7 @@ ka_Authenticate(char *name, char *instance, char *cell, struct ubik_client * con
     int version;
 
     LOCK_GLOBAL_MUTEX;
-    if ((code = des_key_sched(key, schedule))) {
+    if ((code = des_key_sched(ktc_to_cblock(key), schedule))) {
 	UNLOCK_GLOBAL_MUTEX;
 	return KABADKEY;
     }
@@ -551,7 +553,7 @@ ka_Authenticate(char *name, char *instance, char *cell, struct ubik_client * con
     arequest.SeqLen = sizeof(request);
     arequest.SeqBody = (char *)&request;
     des_pcbc_encrypt(arequest.SeqBody, arequest.SeqBody, arequest.SeqLen,
-		     schedule, key, ENCRYPT);
+		     schedule, ktc_to_cblockptr(key), ENCRYPT);
 
     oanswer.MaxSeqLen = sizeof(answer);
     oanswer.SeqLen = 0;
@@ -559,17 +561,16 @@ ka_Authenticate(char *name, char *instance, char *cell, struct ubik_client * con
 
     version = 2;
     code =
-	kawrap_ubik_Call(KAA_AuthenticateV2, conn, 0, name, instance, start,
-			 end, &arequest, &oanswer);
+	kawrap_ubik_Call(KAA_AuthenticateV2, conn, 0, name, instance,
+			 start, end, &arequest, &oanswer, 0, 0);
     if (code == RXGEN_OPCODE) {
 	oanswer.MaxSeqLen = sizeof(answer);
 	oanswer.SeqBody = (char *)&answer;
 	version = 1;
 	code =
 	    ubik_Call(KAA_Authenticate, conn, 0, name, instance, start, end,
-		      &arequest, &oanswer);
+		      &arequest, &oanswer, 0, 0);
 	if (code == RXGEN_OPCODE) {
-	    extern int KAA_Authenticate_old();
 	    oanswer.MaxSeqLen = sizeof(answer_old);
 	    oanswer.SeqBody = (char *)&answer_old;
 	    version = 0;
@@ -588,7 +589,7 @@ ka_Authenticate(char *name, char *instance, char *cell, struct ubik_client * con
 	return KAUBIKCALL;
     }
     des_pcbc_encrypt(oanswer.SeqBody, oanswer.SeqBody, oanswer.SeqLen,
-		     schedule, key, DECRYPT);
+		     schedule, ktc_to_cblockptr(key), DECRYPT);
 
     switch (version) {
     case 1:
@@ -664,7 +665,7 @@ ka_GetToken(char *name, char *instance, char *cell, char *cname, char *cinst, st
     aticket.SeqLen = auth_token->ticketLen;
     aticket.SeqBody = auth_token->ticket;
 
-    code = des_key_sched(&auth_token->sessionKey, schedule);
+    code = des_key_sched(ktc_to_cblock(&auth_token->sessionKey), schedule);
     if (code) {
 	UNLOCK_GLOBAL_MUTEX;
 	return KABADKEY;
@@ -686,7 +687,6 @@ ka_GetToken(char *name, char *instance, char *cell, char *cname, char *cinst, st
 	ubik_Call(KAT_GetTicket, conn, 0, auth_token->kvno, auth_domain,
 		  &aticket, name, instance, &atimes, &oanswer);
     if (code == RXGEN_OPCODE) {
-	extern int KAT_GetTicket_old();
 	oanswer.SeqLen = 0;	/* this may be set by first call */
 	oanswer.MaxSeqLen = sizeof(answer_old);
 	oanswer.SeqBody = (char *)&answer_old;
@@ -707,7 +707,7 @@ ka_GetToken(char *name, char *instance, char *cell, char *cname, char *cinst, st
     }
 
     des_pcbc_encrypt(oanswer.SeqBody, oanswer.SeqBody, oanswer.SeqLen,
-		     schedule, &auth_token->sessionKey, DECRYPT);
+		     schedule, ktc_to_cblockptr(&auth_token->sessionKey), DECRYPT);
 
     switch (version) {
     case 1:
