@@ -36,19 +36,6 @@
 #include <pthread.h>
 #endif
 
-/* These aren't coming from a header, currently, so they must stay here. 
-   Fix elsewhere, or leave alone. */
-extern int RXSTATS_RetrieveProcessRPCStats();
-extern int RXSTATS_RetrievePeerRPCStats();
-extern int RXSTATS_QueryProcessRPCStats();
-extern int RXSTATS_QueryPeerRPCStats();
-extern int RXSTATS_EnableProcessRPCStats();
-extern int RXSTATS_EnablePeerRPCStats();
-extern int RXSTATS_DisableProcessRPCStats();
-extern int RXSTATS_DisablePeerRPCStats();
-extern int RXSTATS_ClearProcessRPCStats();
-extern int RXSTATS_ClearPeerRPCStats();
-
 /*
  * This structure stores the client and server function lists.
  * This is kept separate from the actual interface definitions
@@ -281,8 +268,8 @@ DoClientMountPointCreate(struct cmd_syndesc *as, void *arock)
 	CHECK
     } DoClientMountPointCreate_parm_t;
     afs_status_t st = 0;
-    const char *directory;
-    const char *volume;
+    const char *directory = NULL;
+    const char *volume = NULL;
     vol_type_t vol_type = READ_ONLY;
     vol_check_t vol_check = DONT_CHECK_VOLUME;
 
@@ -333,7 +320,7 @@ DoClientAFSServerGet(struct cmd_syndesc *as, void *arock)
 {
     typedef enum { SERVER } DoClientAFSServerGet_parm_t;
     afs_status_t st = 0;
-    const char *server;
+    const char *server = NULL;
     afs_serverEntry_t entry;
 
     if (as->parms[SERVER].items) {
@@ -481,11 +468,10 @@ DoClientRPCStatsStateGet(struct cmd_syndesc *as, void *arock)
     } DoClientRPCStatsStateGet_parm_t;
     afs_status_t st = 0;
     struct rx_connection *conn;
-    int servAddr = 0;
     afs_stat_source_t type;
     int srvrPort;
-    int typeIsValid;
-    afs_stat_type_t which;
+    int typeIsValid = 0;
+    afs_stat_type_t which = 0;
     afs_RPCStatsState_t state;
 
     if (as->parms[PROCESS].items) {
@@ -539,11 +525,10 @@ DoClientRPCStatsStateEnable(struct cmd_syndesc *as, void *arock)
     typedef enum { SERVER, PROCESS, STAT_TYPE } DoClientRPCStatsEnable_parm_t;
     afs_status_t st = 0;
     struct rx_connection *conn;
-    int servAddr = 0;
     afs_stat_source_t type;
     int srvrPort;
-    int typeIsValid;
-    afs_stat_type_t which;
+    int typeIsValid = 0;
+    afs_stat_type_t which = 0;
 
     if (as->parms[PROCESS].items) {
 	typeIsValid =
@@ -595,11 +580,10 @@ DoClientRPCStatsStateDisable(struct cmd_syndesc *as, void *arock)
     } DoClientRPCStatsDisable_parm_t;
     afs_status_t st = 0;
     struct rx_connection *conn;
-    int servAddr = 0;
     afs_stat_source_t type;
     int srvrPort;
-    int typeIsValid;
-    afs_stat_type_t which;
+    int typeIsValid = 0;
+    afs_stat_type_t which = 0;
 
     if (as->parms[PROCESS].items) {
 	typeIsValid =
@@ -697,14 +681,13 @@ DoClientRPCStatsList(struct cmd_syndesc *as, void *arock)
     typedef enum { SERVER, PROCESS, STAT_TYPE } DoClientRPCStatsList_parm_t;
     afs_status_t st = 0;
     struct rx_connection *conn;
-    int servAddr = 0;
     afs_stat_source_t type;
     int srvrPort;
-    int typeIsValid;
-    afs_stat_type_t which;
+    int typeIsValid = 0;
+    afs_stat_type_t which = 0;
     afs_RPCStats_t stats;
     void *iter;
-    int i;
+    int i = 0;
 
 #ifdef AFS_NT40_ENV
     (pthread_func_list_done
@@ -828,11 +811,10 @@ DoClientRPCStatsClear(struct cmd_syndesc *as, void *arock)
     } DoClientRPCStatsClear_parm_t;
     afs_status_t st = 0;
     struct rx_connection *conn;
-    int servAddr = 0;
     afs_stat_source_t type;
     int srvrPort;
-    int typeIsValid;
-    afs_stat_type_t which;
+    int typeIsValid = 0;
+    afs_stat_type_t which = 0;
     afs_RPCStatsClearFlag_t flag = 0;
     int seen_all = 0;
     int seen_any = 0;
@@ -995,9 +977,8 @@ DoClientRPCStatsVersionGet(struct cmd_syndesc *as, void *arock)
     afs_status_t st = 0;
     struct rx_connection *conn;
     afs_stat_source_t type;
-    int servAddr = 0;
     int srvrPort;
-    int typeIsValid;
+    int typeIsValid = 0;
     afs_RPCStatsVersion_t version;
 
     if (as->parms[PROCESS].items) {
@@ -1050,7 +1031,6 @@ DoClientCMGetServerPrefs(struct cmd_syndesc *as, void *arock)
     afs_status_t st = 0;
     typedef enum { SERVER, PORT } DoClientCMGetServerPrefs_parm_t;
     struct rx_connection *conn;
-    int servAddr = 0;
     int srvrPort = AFSCONF_CALLBACKPORT;
     afs_CMServerPref_t prefs;
     void *iter;
@@ -1120,7 +1100,6 @@ DoClientCMListCells(struct cmd_syndesc *as, void *arock)
     afs_status_t st = 0;
     typedef enum { SERVER, PORT } DoClientCMListCells_parm_t;
     struct rx_connection *conn;
-    int servAddr = 0;
     int srvrPort = AFSCONF_CALLBACKPORT;
     afs_CMListCell_t cellInfo;
     void *iter;
@@ -1175,7 +1154,6 @@ DoClientCMLocalCell(struct cmd_syndesc *as, void *arock)
     afs_status_t st = 0;
     typedef enum { SERVER, PORT } DoClientCMLocalCell_parm_t;
     struct rx_connection *conn;
-    int servAddr = 0;
     int srvrPort = AFSCONF_CALLBACKPORT;
     afs_CMCellName_t cellname;
 
@@ -1234,7 +1212,6 @@ DoClientCMClientConfig(struct cmd_syndesc *as, void *arock)
     afs_status_t st = 0;
     typedef enum { SERVER, PORT } DoClientCMLocalCell_parm_t;
     struct rx_connection *conn;
-    int servAddr = 0;
     int srvrPort = AFSCONF_CALLBACKPORT;
     afs_ClientConfig_t config;
 
