@@ -37,8 +37,6 @@
 #include <afs/param.h>
 #endif
 
-RCSID
-    ("$Header: /cvs/openafs/src/rxkad/bg-fcrypt.c,v 1.7 2005/05/30 04:55:31 shadow Exp $");
 
 #define DEBUG 0
 #ifdef KERNEL
@@ -56,8 +54,6 @@ RCSID
 #include <asm/byteorder.h>
 #endif
 
-#include "afs/longc_procs.h"
-
 #else /* KERNEL */
 
 #include <afs/stds.h>
@@ -76,11 +72,6 @@ RCSID
 #include "private_data.h"
 #include <des/stats.h>
 
-#undef WORDS_BIGENDIAN
-#ifdef AFSBIG_ENDIAN
-#define WORDS_BIGENDIAN 1
-#endif
-
 /*
  * Unrolling of the inner loops helps the most on pentium chips
  * (ca 18%). On risc machines only expect a modest improvement (ca 5%).
@@ -555,8 +546,8 @@ fc_keysched(void *key_, fc_KeySchedule sched)
     const unsigned char *key = key_;
 
     /* Do we have 56 bit longs or even longer longs? */
-#if ((1ul << 31) << 1) && defined(ULONG_MAX) && ((ULONG_MAX >> 55) != 0) && ((1ul << 55) != 0)
-    unsigned long k;		/* k holds all 56 non parity bits */
+#ifdef AFS_64BIT_ENV
+    afs_uint64 k;		/* k holds all 56 non parity bits */
 
     /* Compress out parity bits */
     k = (*key++) >> 1;
