@@ -84,8 +84,6 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/viced/callback.c,v 1.77.2.20 2009/03/19 20:13:02 shadow Exp $");
 
 #include <stdio.h>
 #include <stdlib.h>		/* for malloc() */
@@ -97,6 +95,7 @@ RCSID
 #else
 #include <sys/time.h>
 #include <sys/file.h>
+#include <unistd.h>
 #endif
 #include <afs/assert.h>
 
@@ -1352,7 +1351,7 @@ BreakLaterCallBacks(void)
 			 fe->volid));
 		fid.Volume = fe->volid;
 		*feip = fe->fnext;
-		fe->status &= ~FE_LATER;
+		fe->status &= ~FE_LATER; /* not strictly needed */
 		/* Works since volid is deeper than the largest pointer */
 		tmpfe = (struct object *)fe;
 		tmpfe->next = (struct object *)myfe;
@@ -1930,7 +1929,6 @@ cb_stateVerify(struct fs_dump_state * state)
 	ret = 1;
     }
 
- done:
     return ret;
 }
 
@@ -1964,7 +1962,6 @@ cb_stateVerifyFEHash(struct fs_dump_state * state)
 	}
     }
 
- done:
     return ret;
 }
 
@@ -1984,7 +1981,6 @@ cb_stateVerifyFE(struct fs_dump_state * state, struct FileEntry * fe)
 	ret = 1;
     }
 
- done:
     return ret;
 }
 
@@ -2142,7 +2138,6 @@ cb_stateVerifyTimeoutQueues(struct fs_dump_state * state)
 	}
     }
 
- done:
     return ret;
 }
 
@@ -2427,7 +2422,6 @@ cb_stateRestoreFE(struct fs_dump_state * state)
     struct CBDiskEntry cbdsk[16];
     struct iovec iov[16];
     struct FileEntry * fe;
-    struct CallBack * cb;
 
     iov[0].iov_base = (char *)&hdr;
     iov[0].iov_len = sizeof(hdr);
@@ -2848,8 +2842,8 @@ main(int argc, char **argv)
     }
     now = ReadDump(*argv, timebits);
     if (stats || noptions == 0) {
-	time_t uxtfirst = UXtime(tfirst);
-	printf("The time of the dump was %u %s", (unsigned int) now, ctime(&now));
+	time_t uxtfirst = UXtime(tfirst), tnow = now;
+	printf("The time of the dump was %u %s", (unsigned int) now, ctime(&tnow));
 	printf("The last time cleanup ran was %u %s", (unsigned int) uxtfirst,
 	       ctime(&uxtfirst));
 	PrintCallBackStats();
@@ -2861,7 +2855,7 @@ main(int argc, char **argv)
 	struct FileEntry *fe;
 
 	for (hash = 0; hash < FEHASH_SIZE; hash++) {
-	    for (feip = &HashTable[hash]; fe = itofe(*feip);) {
+	    for (feip = &HashTable[hash]; (fe = itofe(*feip));) {
 		if (!vol || (fe->volid == vol)) {
 		    register struct CallBack *cbnext;
 		    for (cb = itocb(fe->firstcb); cb; cb = cbnext) {
