@@ -16,24 +16,12 @@
 #include <afsconfig.h>
 #include <afs/param.h>
 
-RCSID
-    ("$Header: /cvs/openafs/src/xstat/xstat_fs_test.c,v 1.9 2005/01/14 03:03:31 shadow Exp $");
 
 #include "xstat_fs.h"		/*Interface for xstat_fs module */
 #include <cmd.h>		/*Command line interpreter */
 #include <time.h>
-#ifdef HAVE_STRING_H
 #include <string.h>
-#else
-#ifdef HAVE_STRINGS_H
-#include <strings.h>
-#endif
-#endif
-
-/*
- * External routines that don't have explicit include file definitions.
- */
-extern struct hostent *hostutil_GetHostByName();
+#include <afs/afsutil.h>
 
 /*
  * Command line parameter indices.
@@ -113,21 +101,20 @@ static char *xferOpNames[] = {
  *------------------------------------------------------------------------*/
 
 void
-PrintCallInfo()
+PrintCallInfo(void)
 {				/*PrintCallInfo */
-
-    static char rn[] = "PrintCallInfo";	/*Routine name */
     register int i;		/*Loop variable */
     int numInt32s;		/*# int32words returned */
     afs_int32 *currInt32;	/*Ptr to current afs_int32 value */
     char *printableTime;	/*Ptr to printable time string */
+    time_t probeTime = xstat_fs_Results.probeTime;
 
     /*
      * Just print out the results of the particular probe.
      */
     numInt32s = xstat_fs_Results.data.AFS_CollData_len;
     currInt32 = (afs_int32 *) (xstat_fs_Results.data.AFS_CollData_val);
-    printableTime = ctime((time_t *) & (xstat_fs_Results.probeTime));
+    printableTime = ctime(&probeTime);
     printableTime[strlen(printableTime) - 1] = '\0';
 
     printf("AFS_XSTATSCOLL_CALL_INFO (coll %d) for FS %s\n[Probe %d, %s]\n\n",
@@ -136,7 +123,7 @@ PrintCallInfo()
 	   printableTime);
 
     if (debugging_on)
-	printf("\n[%d entries returned at 0x%x]\n\n", numInt32s, currInt32);
+	printf("\n[%d entries returned at %" AFS_PTR_FMT "]\n\n", numInt32s, currInt32);
 
     for (i = 0; i < numInt32s; i++)
 	printf("%d ", *currInt32++);
@@ -249,7 +236,8 @@ PrintOverallPerfInfo(struct afs_PerfStats *a_ovP)
     printf("\t%10d rx_nFreeCallStructs\n", a_ovP->rx_nFreeCallStructs);
     printf("\t%10d rx_nBusies\n\n", a_ovP->rx_nBusies);
 
-    printf("\t%10d fs_nBusies\n\n", a_ovP->fs_nBusies);
+    printf("\t%10d fs_nBusies\n", a_ovP->fs_nBusies);
+    printf("\t%10d fs_GetCapabilities\n\n", a_ovP->fs_nGetCaps);
     /*
      * Host module fields.
      */
@@ -300,12 +288,12 @@ PrintOpTiming(int a_opIdx, struct fs_stats_opTimingData *a_opTimeP)
     avg = fSumTime / ((double)(a_opTimeP->numSuccesses));
 
     printf
-	("%15s: %d ops (%d OK); sum=%d.%06d, sqr=%d.%06d, min=%d.%06d, max=%d.%06d\n",
+	("%15s: %d ops (%d OK); sum=%ld.%06ld, sqr=%ld.%06ld, min=%ld.%06ld, max=%ld.%06ld\n",
 	 opNames[a_opIdx], a_opTimeP->numOps, a_opTimeP->numSuccesses,
-	 a_opTimeP->sumTime.tv_sec, a_opTimeP->sumTime.tv_usec,
-	 a_opTimeP->sqrTime.tv_sec, a_opTimeP->sqrTime.tv_usec,
-	 a_opTimeP->minTime.tv_sec, a_opTimeP->minTime.tv_usec,
-	 a_opTimeP->maxTime.tv_sec, a_opTimeP->maxTime.tv_usec);
+	 (long)a_opTimeP->sumTime.tv_sec, (long)a_opTimeP->sumTime.tv_usec,
+	 (long)a_opTimeP->sqrTime.tv_sec, (long)a_opTimeP->sqrTime.tv_usec,
+	 (long)a_opTimeP->minTime.tv_sec, (long)a_opTimeP->minTime.tv_usec,
+	 (long)a_opTimeP->maxTime.tv_sec, (long)a_opTimeP->maxTime.tv_usec);
 }
 
 
@@ -341,13 +329,13 @@ PrintXferTiming(int a_opIdx, struct fs_stats_xferData *a_xferP)
     avg = fSumTime / ((double)(a_xferP->numSuccesses));
 
     printf
-	("%s: %d xfers (%d OK), time sum=%d.%06d, sqr=%d.%06d, min=%d.%06d, max=%d.%06d\n",
+	("%s: %d xfers (%d OK), time sum=%ld.%06ld, sqr=%ld.%06ld, min=%ld.%06ld, max=%ld.%06ld\n",
 	 xferOpNames[a_opIdx], a_xferP->numXfers, a_xferP->numSuccesses,
-	 a_xferP->sumTime.tv_sec, a_xferP->sumTime.tv_usec,
-	 a_xferP->sqrTime.tv_sec, a_xferP->sqrTime.tv_usec,
-	 a_xferP->minTime.tv_sec, a_xferP->minTime.tv_usec,
-	 a_xferP->maxTime.tv_sec, a_xferP->maxTime.tv_usec);
-    printf("\t[bytes: sum=%lu, min=%d, max=%d]\n", a_xferP->sumBytes,
+	 (long)a_xferP->sumTime.tv_sec, (long)a_xferP->sumTime.tv_usec,
+	 (long)a_xferP->sqrTime.tv_sec, (long)a_xferP->sqrTime.tv_usec,
+	 (long)a_xferP->minTime.tv_sec, (long)a_xferP->minTime.tv_usec,
+	 (long)a_xferP->maxTime.tv_sec, (long)a_xferP->maxTime.tv_usec);
+    printf("\t[bytes: sum=%d, min=%d, max=%d]\n", a_xferP->sumBytes,
 	   a_xferP->minBytes, a_xferP->maxBytes);
     printf
 	("\t[buckets: 0: %d, 1: %d, 2: %d, 3: %d, 4: %d, 5: %d, 6: %d, 7: %d, 8: %d]\n",
@@ -381,7 +369,7 @@ PrintDetailedPerfInfo(struct fs_stats_DetailedStats *a_detP)
 {
     int currIdx;		/*Loop variable */
 
-    printf("\t%10d epoch\n", a_detP->epoch);
+    printf("\t%10ld epoch\n", (long) a_detP->epoch.tv_sec);
 
     for (currIdx = 0; currIdx < FS_STATS_NUM_RPC_OPS; currIdx++)
 	PrintOpTiming(currIdx, &(a_detP->rpcOpTimes[currIdx]));
@@ -412,15 +400,15 @@ PrintDetailedPerfInfo(struct fs_stats_DetailedStats *a_detP)
  *------------------------------------------------------------------------*/
 
 void
-PrintFullPerfInfo()
+PrintFullPerfInfo(void)
 {
 
-    static char rn[] = "PrintFullPerfInfo";	/*Routine name */
     static afs_int32 fullPerfInt32s = (sizeof(struct fs_stats_FullPerfStats) >> 2);	/*Correct # int32s to rcv */
     afs_int32 numInt32s;	/*# int32words received */
     struct fs_stats_FullPerfStats *fullPerfP;	/*Ptr to full perf stats */
     char *printableTime;	/*Ptr to printable time
 				 * string */
+    time_t probeTime = xstat_fs_Results.probeTime;
 
     numInt32s = xstat_fs_Results.data.AFS_CollData_len;
     if (numInt32s != fullPerfInt32s) {
@@ -429,7 +417,7 @@ PrintFullPerfInfo()
 	return;
     }
 
-    printableTime = ctime((time_t *) & (xstat_fs_Results.probeTime));
+    printableTime = ctime(&probeTime);
     printableTime[strlen(printableTime) - 1] = '\0';
     fullPerfP = (struct fs_stats_FullPerfStats *)
 	(xstat_fs_Results.data.AFS_CollData_val);
@@ -465,13 +453,13 @@ PrintFullPerfInfo()
  *------------------------------------------------------------------------*/
 
 void
-PrintPerfInfo()
+PrintPerfInfo(void)
 {
-    static char rn[] = "PrintPerfInfo";	/*Routine name */
     static afs_int32 perfInt32s = (sizeof(struct afs_PerfStats) >> 2);	/*Correct # int32s to rcv */
     afs_int32 numInt32s;	/*# int32words received */
     struct afs_PerfStats *perfP;	/*Ptr to performance stats */
     char *printableTime;	/*Ptr to printable time string */
+    time_t probeTime = xstat_fs_Results.probeTime;
 
     numInt32s = xstat_fs_Results.data.AFS_CollData_len;
     if (numInt32s != perfInt32s) {
@@ -480,7 +468,7 @@ PrintPerfInfo()
 	return;
     }
 
-    printableTime = ctime((time_t *) & (xstat_fs_Results.probeTime));
+    printableTime = ctime(&probeTime);
     printableTime[strlen(printableTime) - 1] = '\0';
     perfP = (struct afs_PerfStats *)
 	(xstat_fs_Results.data.AFS_CollData_val);
@@ -493,6 +481,34 @@ PrintPerfInfo()
     PrintOverallPerfInfo(perfP);
 }
 
+static char *CbCounterStrings[] = {
+    "DeleteFiles",
+    "DeleteCallBacks",
+    "BreakCallBacks",
+    "AddCallBack",
+    "GotSomeSpaces",
+    "DeleteAllCallBacks",
+    "nFEs", "nCBs", "nblks",
+    "CBsTimedOut",
+    "nbreakers",
+    "GSS1", "GSS2", "GSS3", "GSS4", "GSS5"
+};
+
+
+void
+PrintCbCounters(void) {
+    int numInt32s = sizeof(CbCounterStrings)/sizeof(char *);
+    int i;
+    afs_int32 *val=xstat_fs_Results.data.AFS_CollData_val;
+
+    if (numInt32s > xstat_fs_Results.data.AFS_CollData_len)
+	numInt32s = xstat_fs_Results.data.AFS_CollData_len;
+
+    for (i=0; i<numInt32s; i++) {
+	printf("\t%10u %s\n", val[i], CbCounterStrings[i]);
+    }
+}
+
 
 /*------------------------------------------------------------------------
  * FS_Handler
@@ -519,7 +535,7 @@ PrintPerfInfo()
  *------------------------------------------------------------------------*/
 
 int
-FS_Handler()
+FS_Handler(void)
 {
     static char rn[] = "FS_Handler";	/*Routine name */
 
@@ -549,6 +565,10 @@ FS_Handler()
 	PrintFullPerfInfo();
 	break;
 
+    case AFS_XSTATSCOLL_CBSTATS:
+	PrintCbCounters();
+	break;
+
     default:
 	printf("** Unknown collection: %d\n",
 	       xstat_fs_Results.collectionNumber);
@@ -630,7 +650,7 @@ CountListItems(struct cmd_item *a_firstItem)
  *------------------------------------------------------------------------*/
 
 int
-RunTheTest(struct cmd_syndesc *a_s)
+RunTheTest(struct cmd_syndesc *a_s, void *dummy)
 {
     static char rn[] = "RunTheTest";	/*Routine name */
     int code;			/*Return code */
@@ -687,7 +707,11 @@ RunTheTest(struct cmd_syndesc *a_s)
      */
     curr_item = a_s->parms[P_FS_NAMES].items;
     for (currFS = 0; currFS < numFSs; currFS++) {
+#if defined(AFS_DARWIN_ENV) || defined(AFS_FBSD_ENV)
+	FSSktArray[currFS].sin_family = AF_INET;	/*Internet family */
+#else
 	FSSktArray[currFS].sin_family = htons(AF_INET);	/*Internet family */
+#endif
 	FSSktArray[currFS].sin_port = htons(7000);	/*FileServer port */
 	he = hostutil_GetHostByName(curr_item->data);
 	if (he == NULL) {
@@ -755,7 +779,7 @@ RunTheTest(struct cmd_syndesc *a_s)
 	 * One-shot operation; just wait for the collection to be done.
 	 */
 	if (debugging_on)
-	    printf("[%s] Calling LWP_WaitProcess() on event 0x%x\n", rn,
+	    printf("[%s] Calling LWP_WaitProcess() on event %" AFS_PTR_FMT "\n", rn,
 		   &terminationEvent);
 	waitCode = LWP_WaitProcess(&terminationEvent);
 	if (debugging_on)
